# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: vivintpy/proto/beam.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19vivintpy/proto/beam.proto\x12\x04\x62\x65\x61m\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1bgoogle/protobuf/empty.proto\"~\n\x14SetDeviceNameRequest\x12\x14\n\x08panel_id\x18\x01 \x01(\x03\x42\x02\x18\x01\x12\x15\n\tdevice_id\x18\x02 \x01(\rB\x02\x18\x01\x12\x0c\n\x04name\x18\x03 \x01(\t\x12+\n\x06header\x18\x04 \x01(\x0b\x32\x1b.beam.SettingsRequestHeader\"9\n\x15SetDeviceNameResponse\x12 \n\x08response\x18\x01 \x01(\x0b\x32\x0e.beam.Response\"D\n\x1dGetCameraTechnicalInfoRequest\x12\x10\n\x08panel_id\x18\x01 \x01(\x03\x12\x11\n\tdevice_id\x18\x02 \x01(\r\"e\n\x1eGetCameraTechnicalInfoResponse\x12 \n\x08response\x18\x01 \x01(\x0b\x32\x0e.beam.Response\x12!\n\x04info\x18\x02 \x01(\x0b\x32\x13.beam.TechnicalInfo\"t\n\x18GetCameraSettingsRequest\x12\x14\n\x08panel_id\x18\x01 \x01(\x03\x42\x02\x18\x01\x12\x15\n\tdevice_id\x18\x02 \x01(\rB\x02\x18\x01\x12+\n\x06header\x18\x03 \x01(\x0b\x32\x1b.beam.SettingsRequestHeader\"\xcd\x1b\n\x19GetCameraSettingsResponse\x12 \n\x08response\x18\x01 \x01(\x0b\x32\x0e.beam.Response\x12\x14\n\x0cprivacy_mode\x18\x02 \x01(\x08\x12\x18\n\x10playback_enabled\x18\x04 \x01(\x08\x12\x30\n\x11\x64\x65tection_windows\x18\x06 \x03(\x0b\x32\x15.beam.DetectionWindow\x12\x14\n\x0c\x63hime_volume\x18\x07 \x01(\x05\x12\x12\n\nmute_chime\x18\x08 \x01(\x08\x12)\n\rvideo_quality\x18\t \x01(\x0e\x32\x12.beam.VideoQuality\x12\x14\n\x0cnight_vision\x18\n \x01(\x08\x12\x0c\n\x04\x66lip\x18\x0b \x01(\x08\x12\x11\n\tzoom_lock\x18\x0c \x01(\x08\x12\x0e\n\x06led_on\x18\r \x01(\x08\x12\x14\n\x0crecord_audio\x18\x0e \x01(\x08\x12+\n\x0e\x64oorbell_chime\x18\x0f \x01(\x0e\x32\x13.beam.DoorbellChime\x12)\n\rvisitor_chime\x18\x10 \x01(\x0e\x32\x12.beam.VisitorChime\x12\x14\n\x0c\x65xtend_chime\x18\x11 \x01(\x08\x12\x12\n\nquiet_mode\x18\x12 \x01(\x08\x12\x0c\n\x04name\x18\x13 \x01(\t\x12!\n\x04info\x18\x14 \x01(\x0b\x32\x13.beam.TechnicalInfo\x12\x11\n\tir_led_on\x18\x15 \x01(\x08\x12(\n\x0c\x63\x61pabilities\x18\x16 \x01(\x0b\x32\x12.beam.Capabilities\x12\x34\n\x10\x61ggression_level\x18\x03 \x01(\x0e\x32\x1a.beam.DeterAggressionLevel\x12+\n\ndeter_type\x18\x17 \x01(\x0e\x32\x17.beam.DeterScheduleType\x12+\n\x0e\x64\x65ter_schedule\x18\x18 \x01(\x0b\x32\x13.beam.DeterSchedule\x12\x41\n\x18property_boundary_points\x18\x19 \x03(\x0b\x32\x1f.beam.PropertyBoundaryPointList\x12>\n\x15\x64\x65ter_boundary_points\x18\x1a \x03(\x0b\x32\x1f.beam.PropertyBoundaryPointList\x12\x30\n\x11\x64\x65ter_light_color\x18\x1b \x01(\x0e\x32\x15.beam.DeterLightColor\x12\x34\n\x13\x64\x65ter_light_pattern\x18\x1c \x01(\x0e\x32\x17.beam.DeterLightPattern\x12\x17\n\x0flinger_duration\x18\x1d \x01(\r\x12\x14\n\x0c\x65xtend_siren\x18\x1e \x01(\x08\x12\x14\n\x0clurker_deter\x18\x1f \x01(\x08\x12\x32\n\x12record_for_regions\x18  \x01(\x0e\x32\x16.beam.RecordForRegions\x12!\n\x19record_on_lurker_detected\x18! \x01(\x08\x12\"\n\x1arecord_on_package_detected\x18\" \x01(\x08\x12!\n\x19record_on_person_detected\x18# \x01(\x08\x12\x1d\n\x15\x61nalytics_sensitivity\x18$ \x01(\x05\x12)\n\rpackage_chime\x18% \x01(\x0e\x32\x12.beam.PackageChime\x12\x14\n\x0c\x63onnected_to\x18& \x01(\t\x12\x1e\n\x16\x63\x61mera_connection_type\x18\' \x01(\t\x12$\n\x1cvideo_clip_analytics_allowed\x18( \x01(\x08\x12\x15\n\rpackage_watch\x18) \x01(\x08\x12!\n\x19notify_on_person_detected\x18* \x01(\x08\x12!\n\x19notify_on_lurker_detected\x18+ \x01(\x08\x12\x31\n\x11\x64oorbell_position\x18, \x01(\x0e\x32\x16.beam.DoorbellPosition\x12\x1e\n\x16notify_on_package_seen\x18- \x01(\x08\x12\x1f\n\x17notify_on_package_moved\x18. \x01(\x08\x12\x1e\n\x16notify_on_vehicle_seen\x18/ \x01(\x08\x12\x1d\n\x15notify_on_animal_seen\x18\x30 \x01(\x08\x12?\n\x1apackage_delivery_locations\x18\x31 \x03(\x0b\x32\x1b.beam.PropertyBoundaryPoint\x12!\n\x19smart_sentry_snooze_until\x18\x32 \x01(\r\x12\x1f\n\x13package_watch_state\x18\x34 \x01(\x08\x42\x02\x18\x01\x12\x1e\n\x16\x64\x65ter_schedule_version\x18\x35 \x01(\r\x12\x15\n\rdeter_on_duty\x18\x36 \x01(\x08\x12-\n\x0c\x64\x65ter_reason\x18\x37 \x01(\x0e\x32\x17.beam.DeterScheduleType\x12\x17\n\x0f\x64\x65ter_timestamp\x18\x38 \x01(\x04\x12\x17\n\x0f\x64\x65ter_user_info\x18\x39 \x01(\t\x12\x16\n\x0e\x64\x65ter_override\x18: \x01(\x08\x12$\n\x1c\x64\x65ter_override_end_timestamp\x18; \x01(\x04\x12;\n\x1a\x64\x65ter_valid_schedule_types\x18< \x03(\x0e\x32\x17.beam.DeterScheduleType\x12%\n\x1dsmart_sentry_snooze_user_info\x18= \x01(\t\x12\x17\n\x0frecord_on_deter\x18> \x01(\x08\x12\x17\n\x0fnotify_on_deter\x18? \x01(\x08\x12\x10\n\x08\x66\x65\x61tures\x18@ \x03(\t\x12\x36\n\x0f\x44\x65terScheduleV2\x18\x41 \x01(\x0b\x32\x1d.beam.DeterScheduleSettingsV2\x12\x18\n\x10\x61nalytics_opt_in\x18\x42 \x01(\x08\x12*\n\"dynamic_doorbell_chime_category_id\x18\x43 \x01(\t\x12!\n\x19\x64ynamic_doorbell_chime_id\x18\x44 \x01(\t\x12\"\n\x1a\x64ynamic_doorbell_chime_url\x18\x45 \x01(\t\x12)\n!dynamic_doorbell_chime_sha256hash\x18\x46 \x01(\t\x12\x1e\n\x16record_on_vehicle_seen\x18G \x01(\x08\x12 \n\x18notify_on_doorbell_press\x18H \x01(\x08\x12 \n\x18record_on_doorbell_press\x18I \x01(\x08\x12\x32\n\x12\x61spect_ratio_tuple\x18J \x01(\x0b\x32\x16.beam.AspectRatioTuple\x12?\n\x16\x61nimal_boundary_points\x18K \x03(\x0b\x32\x1f.beam.PropertyBoundaryPointList\x12@\n\x17vehicle_boundary_points\x18L \x03(\x0b\x32\x1f.beam.PropertyBoundaryPointList\x12@\n\x17package_boundary_points\x18M \x03(\x0b\x32\x1f.beam.PropertyBoundaryPointList\x12*\n\"command_control_availability_state\x18N \x01(\x03\x12\'\n\x1fnotification_availability_state\x18O \x01(\x03\x12\"\n\x1anetwork_availability_state\x18P \x01(\x03\x12!\n\x19stream_availability_state\x18Q \x01(\x03\x12!\n\x19notify_on_vehicle_leaving\x18R \x01(\x08\x12\x1b\n\x13spotlight_installed\x18S \x01(\x08\x12+\n\x0espotlight_mode\x18T \x01(\x0e\x32\x13.beam.SpotlightMode\x12\x1c\n\x14spotlight_brightness\x18U \x01(\x02\x12\x1b\n\x13spotlight_num_zones\x18V \x01(\x05\x12(\n enabled_spotlight_zones_bitfield\x18W \x01(\r\x12\x18\n\x10spotlight_follow\x18X \x01(\x08\x12\x41\n!spotlight_deter_lighting_behavior\x18Y \x01(\x0b\x32\x16.beam.LightingBehavior\x12/\n\x10spotlight_status\x18Z \x01(\x0e\x32\x15.beam.SpotlightStatus\x12\x1d\n\x15spotlight_temperature\x18[ \x01(\x02\x12 \n\x18spotlight_driver_version\x18\\ \x01(\t\x12\"\n\x1aspotlight_hardware_version\x18] \x01(\t\x12*\n\"spotlight_light_on_person_detected\x18^ \x01(\x08\x12=\n\x15spotlight_calibration\x18_ \x01(\x0b\x32\x1e.beam.SpotlightCalibrationData\x12\x1c\n\x14spotlight_night_mode\x18` \x01(\x08\x12\x1d\n\x15spotlight_night_light\x18\x61 \x01(\x08\x12\x1d\n\x15spotlight_flood_state\x18\x62 \x01(\x08\"5\n\x0ePanelDeviceIds\x12\x10\n\x08panel_id\x18\x01 \x01(\x03\x12\x11\n\tdevice_id\x18\x02 \x01(\r\"Y\n\x13StandaloneCameraIds\x12\x1a\n\x12smarthomesystem_id\x18\x01 \x01(\x03\x12\x13\n\x0b\x64\x65vice_uuid\x18\x02 \x01(\t\x12\x11\n\tdevice_id\x18\x03 \x01(\t\"\xd6\x01\n\x15SettingsRequestHeader\x12/\n\x0fpanel_device_id\x18\x01 \x01(\x0b\x32\x14.beam.PanelDeviceIdsH\x00\x12\x19\n\x0b\x64\x65vice_uuid\x18\x02 \x01(\tB\x02\x18\x01H\x00\x12\x39\n\x14standalone_camera_id\x18\x03 \x01(\x0b\x32\x19.beam.StandaloneCameraIdsH\x00\x12\x13\n\x0b\x64\x65vice_type\x18\x04 \x01(\t\x12\x1a\n\x12standalone_enabled\x18\x05 \x01(\x08\x42\x05\n\x03ids\">\n\x17GetPanelSettingsRequest\x12\x10\n\x08panel_id\x18\x01 \x01(\x03\x12\x11\n\tdevice_id\x18\x02 \x01(\r\"T\n\x18GetPanelSettingsResponse\x12 \n\x08response\x18\x01 \x01(\x0b\x32\x0e.beam.Response\x12\x16\n\x0e\x64oorbell_muted\x18\x02 \x01(\x08\"X\n\x1bSetCameraPrivacyModeRequest\x12\x10\n\x08panel_id\x18\x01 \x01(\x03\x12\x11\n\tdevice_id\x18\x02 \x01(\r\x12\x14\n\x0cprivacy_mode\x18\x03 \x01(\x08\"@\n\x1cSetCameraPrivacyModeResponse\x12 \n\x08response\x18\x01 \x01(\x0b\x32\x0e.beam.Response\"`\n\x1fSetCameraPlaybackEnabledRequest\x12\x10\n\x08panel_id\x18\x01 \x01(\x03\x12\x11\n\tdevice_id\x18\x02 \x01(\r\x12\x18\n\x10playback_enabled\x18\x03 \x01(\x08\"D\n SetCameraPlaybackEnabledResponse\x12 \n\x08response\x18\x01 \x01(\x0b\x32\x0e.beam.Response\"s\n\x1aSetDetectionWindowsRequest\x12\x10\n\x08panel_id\x18\x01 \x01(\x03\x12\x11\n\tdevice_id\x18\x02 \x01(\r\x12\x30\n\x11\x64\x65tection_windows\x18\x03 \x03(\x0b\x32\x15.beam.DetectionWindow\"?\n\x1bSetDetectionWindowsResponse\x12 \n\x08response\x18\x01 \x01(\x0b\x32\x0e.beam.Response\"L\n\x15SetChimeVolumeRequest\x12\x10\n\x08panel_id\x18\x01 \x01(\x03\x12\x11\n\tdevice_id\x18\x02 \x01(\r\x12\x0e\n\x06volume\x18\x03 \x01(\x05\":\n\x16SetChimeVolumeResponse\x12 \n\x08response\x18\x01 \x01(\x0b\x32\x0e.beam.Response\"H\n\x13SetChimeMuteRequest\x12\x10\n\x08panel_id\x18\x01 \x01(\x03\x12\x11\n\tdevice_id\x18\x02 \x01(\r\x12\x0c\n\x04mute\x18\x03 \x01(\x08\"8\n\x14SetChimeMuteResponse\x12 \n\x08response\x18\x01 \x01(\x0b\x32\x0e.beam.Response\"b\n\x16SetVideoQualityRequest\x12\x10\n\x08panel_id\x18\x01 \x01(\x03\x12\x11\n\tdevice_id\x18\x02 \x01(\r\x12#\n\x07quality\x18\x03 \x01(\x0e\x32\x12.beam.VideoQuality\";\n\x17SetVideoQualityResponse\x12 \n\x08response\x18\x01 \x01(\x0b\x32\x0e.beam.Response\"R\n\x15SetNightVisionRequest\x12\x10\n\x08panel_id\x18\x01 \x01(\x03\x12\x11\n\tdevice_id\x18\x02 \x01(\r\x12\x14\n\x0cnight_vision\x18\x03 \x01(\x08\":\n\x16SetNightVisionResponse\x12 \n\x08response\x18\x01 \x01(\x0b\x32\x0e.beam.Response\"I\n\x0fSetIRLEDRequest\x12\x10\n\x08panel_id\x18\x01 \x01(\x03\x12\x11\n\tdevice_id\x18\x02 \x01(\r\x12\x11\n\tir_led_on\x18\x03 \x01(\x08\"4\n\x10SetIRLEDResponse\x12 \n\x08response\x18\x01 \x01(\x0b\x32\x0e.beam.Response\"R\n\x15SetRotateImageRequest\x12\x10\n\x08panel_id\x18\x01 \x01(\x03\x12\x11\n\tdevice_id\x18\x02 \x01(\r\x12\x14\n\x0crotate_image\x18\x03 \x01(\x08\":\n\x16SetRotateImageResponse\x12 \n\x08response\x18\x01 \x01(\x0b\x32\x0e.beam.Response\"T\n\x16SetMaintainZoomRequest\x12\x10\n\x08panel_id\x18\x01 \x01(\x03\x12\x11\n\tdevice_id\x18\x02 \x01(\r\x12\x15\n\rmaintain_zoom\x18\x03 \x01(\x08\";\n\x17SetMaintainZoomResponse\x12 \n\x08response\x18\x01 \x01(\x0b\x32\x0e.beam.Response\"R\n\x15SetStatusLightRequest\x12\x10\n\x08panel_id\x18\x01 \x01(\x03\x12\x11\n\tdevice_id\x18\x02 \x01(\r\x12\x14\n\x0cstatus_light\x18\x03 \x01(\x08\":\n\x16SetStatusLightResponse\x12 \n\x08response\x18\x01 \x01(\x0b\x32\x0e.beam.Response\"\x8d\x01\n\x18SetAudioRecordingRequest\x12\x14\n\x08panel_id\x18\x01 \x01(\x03\x42\x02\x18\x01\x12\x15\n\tdevice_id\x18\x02 \x01(\rB\x02\x18\x01\x12\x17\n\x0f\x61udio_recording\x18\x03 \x01(\x08\x12+\n\x06header\x18\x04 \x01(\x0b\x32\x1b.beam.SettingsRequestHeader\"=\n\x19SetAudioRecordingResponse\x12 \n\x08response\x18\x01 \x01(\x0b\x32\x0e.beam.Response\"\xcc\x01\n\x17SetDoorbellChimeRequest\x12\x14\n\x08panel_id\x18\x01 \x01(\x03\x42\x02\x18\x01\x12\x15\n\tdevice_id\x18\x02 \x01(\rB\x02\x18\x01\x12\"\n\x05\x63hime\x18\x03 \x01(\x0e\x32\x13.beam.DoorbellChime\x12\x1a\n\x12standalone_enabled\x18\x04 \x01(\x08\x12\x17\n\x0b\x64\x65vice_uuid\x18\x05 \x01(\tB\x02\x18\x01\x12+\n\x06header\x18\x06 \x01(\x0b\x32\x1b.beam.SettingsRequestHeader\"<\n\x18SetDoorbellChimeResponse\x12 \n\x08response\x18\x01 \x01(\x0b\x32\x0e.beam.Response\"M\n\x17SetDoorbellMutedRequest\x12\x10\n\x08panel_id\x18\x01 \x01(\x03\x12\x11\n\tdevice_id\x18\x02 \x01(\r\x12\r\n\x05muted\x18\x03 \x01(\x08\"<\n\x18SetDoorbellMutedResponse\x12 \n\x08response\x18\x01 \x01(\x0b\x32\x0e.beam.Response\"`\n\x16SetVisitorChimeRequest\x12\x10\n\x08panel_id\x18\x01 \x01(\x03\x12\x11\n\tdevice_id\x18\x02 \x01(\r\x12!\n\x05\x63hime\x18\x03 \x01(\x0e\x32\x12.beam.VisitorChime\";\n\x17SetVisitorChimeResponse\x12 \n\x08response\x18\x01 \x01(\x0b\x32\x0e.beam.Response\"\x95\x01\n\x16SetPackageChimeRequest\x12\x14\n\x08panel_id\x18\x01 \x01(\x03\x42\x02\x18\x01\x12\x15\n\tdevice_id\x18\x02 \x01(\rB\x02\x18\x01\x12!\n\x05\x63hime\x18\x03 \x01(\x0e\x32\x12.beam.PackageChime\x12+\n\x06header\x18\x04 \x01(\x0b\x32\x1b.beam.SettingsRequestHeader\";\n\x17SetPackageChimeResponse\x12 \n\x08response\x18\x01 \x01(\x0b\x32\x0e.beam.Response\"s\n$SetUseAsDoorbellChimeExtenderRequest\x12\x10\n\x08panel_id\x18\x01 \x01(\x03\x12\x11\n\tdevice_id\x18\x02 \x01(\r\x12&\n\x1euse_as_doorbell_chime_extender\x18\x03 \x01(\x08\"I\n%SetUseAsDoorbellChimeExtenderResponse\x12 \n\x08response\x18\x01 \x01(\x0b\x32\x0e.beam.Response\"R\n\x15SetExtendSirenRequest\x12\x10\n\x08panel_id\x18\x01 \x01(\x03\x12\x11\n\tdevice_id\x18\x02 \x01(\r\x12\x14\n\x0c\x65xtend_siren\x18\x03 \x01(\x08\":\n\x16SetExtendSirenResponse\x12 \n\x08response\x18\x01 \x01(\x0b\x32\x0e.beam.Response\"N\n\x13SetQuietModeRequest\x12\x10\n\x08panel_id\x18\x01 \x01(\x03\x12\x11\n\tdevice_id\x18\x02 \x01(\r\x12\x12\n\nquiet_mode\x18\x03 \x01(\x08\"8\n\x14SetQuietModeResponse\x12 \n\x08response\x18\x01 \x01(\x0b\x32\x0e.beam.Response\"t\n\x18GetAnalyticsOptInRequest\x12\x14\n\x08panel_id\x18\x01 \x01(\x03\x42\x02\x18\x01\x12\x15\n\tdevice_id\x18\x02 \x01(\rB\x02\x18\x01\x12+\n\x06header\x18\x03 \x01(\x0b\x32\x1b.beam.SettingsRequestHeader\"M\n\x19GetAnalyticsOptInResponse\x12 \n\x08response\x18\x01 \x01(\x0b\x32\x0e.beam.Response\x12\x0e\n\x06opt_in\x18\x02 \x01(\x08\"\x95\x01\n\x18SetAnalyticsOptInRequest\x12\x14\n\x08panel_id\x18\x01 \x01(\x03\x42\x02\x18\x01\x12\x15\n\tdevice_id\x18\x02 \x01(\rB\x02\x18\x01\x12\x0e\n\x06opt_in\x18\x03 \x01(\x08\x12\x0f\n\x07version\x18\x04 \x01(\r\x12+\n\x06header\x18\x05 \x01(\x0b\x32\x1b.beam.SettingsRequestHeader\"=\n\x19SetAnalyticsOptInResponse\x12 \n\x08response\x18\x01 \x01(\x0b\x32\x0e.beam.Response\"\x7f\n\x12SetNotifyOnRequest\x12\x14\n\x08panel_id\x18\x01 \x01(\x03\x42\x02\x18\x01\x12\x15\n\tdevice_id\x18\x02 \x01(\rB\x02\x18\x01\x12\x0f\n\x07\x65nabled\x18\x03 \x01(\x08\x12+\n\x06header\x18\x04 \x01(\x0b\x32\x1b.beam.SettingsRequestHeader\"7\n\x13SetNotifyOnResponse\x12 \n\x08response\x18\x01 \x01(\x0b\x32\x0e.beam.Response\"=\n\x16RestoreDefaultsRequest\x12\x10\n\x08panel_id\x18\x01 \x01(\x03\x12\x11\n\tdevice_id\x18\x02 \x01(\r\";\n\x17RestoreDefaultsResponse\x12 \n\x08response\x18\x01 \x01(\x0b\x32\x0e.beam.Response\"s\n\x18\x41\x64justCameraToXyzRequest\x12\x10\n\x08panel_id\x18\x01 \x01(\x03\x12\x11\n\tdevice_id\x18\x02 \x01(\r\x12\x11\n\tstream_id\x18\x03 \x01(\t\x12\t\n\x01x\x18\x04 \x01(\r\x12\t\n\x01y\x18\x05 \x01(\r\x12\t\n\x01z\x18\x06 \x01(\r\"=\n\x19\x41\x64justCameraToXyzResponse\x12 \n\x08response\x18\x01 \x01(\x0b\x32\x0e.beam.Response\"O\n\x13RebootCameraRequest\x12\x10\n\x08panel_id\x18\x01 \x01(\x03\x12\x11\n\tdevice_id\x18\x02 \x01(\r\x12\x13\n\x0b\x64\x65vice_type\x18\x03 \x01(\t\"8\n\x14RebootCameraResponse\x12 \n\x08response\x18\x01 \x01(\x0b\x32\x0e.beam.Response\"r\n\x16\x44\x65leteAllEventsRequest\x12\x14\n\x08panel_id\x18\x01 \x01(\x03\x42\x02\x18\x01\x12\x15\n\tdevice_id\x18\x02 \x01(\rB\x02\x18\x01\x12+\n\x06header\x18\x03 \x01(\x0b\x32\x1b.beam.SettingsRequestHeader\";\n\x17\x44\x65leteAllEventsResponse\x12 \n\x08response\x18\x01 \x01(\x0b\x32\x0e.beam.Response\":\n\x13\x44\x65leteCameraRequest\x12\x10\n\x08panel_id\x18\x01 \x01(\x03\x12\x11\n\tdevice_id\x18\x02 \x01(\r\"8\n\x14\x44\x65leteCameraResponse\x12 \n\x08response\x18\x01 \x01(\x0b\x32\x0e.beam.Response\"Q\n\x19SetCameraListOrderRequest\x12\x10\n\x08panel_id\x18\x01 \x01(\x03\x12\x0f\n\x07user_id\x18\x02 \x01(\t\x12\x11\n\tdevice_id\x18\x03 \x03(\r\">\n\x1aSetCameraListOrderResponse\x12 \n\x08response\x18\x01 \x01(\x0b\x32\x0e.beam.Response\"R\n\x15SetLurkerDeterRequest\x12\x10\n\x08panel_id\x18\x01 \x01(\x03\x12\x11\n\tdevice_id\x18\x02 \x01(\r\x12\x14\n\x0clurker_deter\x18\x03 \x01(\x08\":\n\x16SetLurkerDeterResponse\x12 \n\x08response\x18\x01 \x01(\x0b\x32\x0e.beam.Response\"T\n\x1bSetSmartSentrySnoozeRequest\x12\x10\n\x08panel_id\x18\x01 \x01(\x03\x12\x11\n\tdevice_id\x18\x02 \x01(\r\x12\x10\n\x08\x64uration\x18\x03 \x01(\r\"@\n\x1cSetSmartSentrySnoozeResponse\x12 \n\x08response\x18\x01 \x01(\x0b\x32\x0e.beam.Response\"T\n\x16SetPackageWatchRequest\x12\x10\n\x08panel_id\x18\x01 \x01(\x03\x12\x11\n\tdevice_id\x18\x02 \x01(\r\x12\x15\n\rpackage_watch\x18\x03 \x01(\x08\";\n\x17SetPackageWatchResponse\x12 \n\x08response\x18\x01 \x01(\x0b\x32\x0e.beam.Response\"\xab\x01\n\x1aSetPropertyBoundaryRequest\x12\x14\n\x08panel_id\x18\x01 \x01(\x03\x42\x02\x18\x01\x12\x15\n\tdevice_id\x18\x02 \x01(\rB\x02\x18\x01\x12\x33\n\npoint_list\x18\x03 \x03(\x0b\x32\x1f.beam.PropertyBoundaryPointList\x12+\n\x06header\x18\x04 \x01(\x0b\x32\x1b.beam.SettingsRequestHeader\"?\n\x1bSetPropertyBoundaryResponse\x12 \n\x08response\x18\x01 \x01(\x0b\x32\x0e.beam.Response\"\x8c\x01\n\x17SetDeterScheduleRequest\x12\x10\n\x08panel_id\x18\x01 \x01(\x03\x12\x11\n\tdevice_id\x18\x02 \x01(\r\x12%\n\x04type\x18\x03 \x01(\x0e\x32\x17.beam.DeterScheduleType\x12%\n\x08schedule\x18\x04 \x01(\x0b\x32\x13.beam.DeterSchedule\"<\n\x18SetDeterScheduleResponse\x12 \n\x08response\x18\x01 \x01(\x0b\x32\x0e.beam.Response\"z\n\x19SetDeterScheduleV2Request\x12\x10\n\x08panel_id\x18\x01 \x01(\x03\x12\x11\n\tdevice_id\x18\x02 \x01(\r\x12\x38\n\x11schedule_settings\x18\x03 \x01(\x0b\x32\x1d.beam.DeterScheduleSettingsV2\">\n\x1aSetDeterScheduleV2Response\x12 \n\x08response\x18\x01 \x01(\x0b\x32\x0e.beam.Response\"w\n\x17\x44\x65terScheduleSettingsV2\x12\x35\n\x14\x64\x65ter_schedule_types\x18\x01 \x03(\x0e\x32\x17.beam.DeterScheduleType\x12%\n\x08schedule\x18\x02 \x01(\x0b\x32\x13.beam.DeterSchedule\"1\n\x10\x41spectRatioTuple\x12\r\n\x05width\x18\x01 \x01(\r\x12\x0e\n\x06height\x18\x02 \x01(\r\"p\n\x1eSetDeterAggressionLevelRequest\x12\x10\n\x08panel_id\x18\x01 \x01(\x03\x12\x11\n\tdevice_id\x18\x02 \x01(\r\x12)\n\x05level\x18\x03 \x01(\x0e\x32\x1a.beam.DeterAggressionLevel\"C\n\x1fSetDeterAggressionLevelResponse\x12 \n\x08response\x18\x01 \x01(\x0b\x32\x0e.beam.Response\"f\n\x19SetDeterLightColorRequest\x12\x10\n\x08panel_id\x18\x01 \x01(\x03\x12\x11\n\tdevice_id\x18\x02 \x01(\r\x12$\n\x05\x63olor\x18\x03 \x01(\x0e\x32\x15.beam.DeterLightColor\">\n\x1aSetDeterLightColorResponse\x12 \n\x08response\x18\x01 \x01(\x0b\x32\x0e.beam.Response\"l\n\x1bSetDeterLightPatternRequest\x12\x10\n\x08panel_id\x18\x01 \x01(\x03\x12\x11\n\tdevice_id\x18\x02 \x01(\r\x12(\n\x07pattern\x18\x03 \x01(\x0e\x32\x17.beam.DeterLightPattern\"@\n\x1cSetDeterLightPatternResponse\x12 \n\x08response\x18\x01 \x01(\x0b\x32\x0e.beam.Response\"f\n\x17SetDeterOverrideRequest\x12\x10\n\x08panel_id\x18\x01 \x01(\x03\x12\x11\n\tdevice_id\x18\x02 \x01(\r\x12\x0f\n\x07\x65nabled\x18\x03 \x01(\x08\x12\x15\n\rend_timestamp\x18\x04 \x01(\x03\"<\n\x18SetDeterOverrideResponse\x12 \n\x08response\x18\x01 \x01(\x0b\x32\x0e.beam.Response\"Q\n\x18SetLingerDurationRequest\x12\x10\n\x08panel_id\x18\x01 \x01(\x03\x12\x11\n\tdevice_id\x18\x02 \x01(\r\x12\x10\n\x08\x64uration\x18\x03 \x01(\r\"=\n\x19SetLingerDurationResponse\x12 \n\x08response\x18\x01 \x01(\x0b\x32\x0e.beam.Response\"\xa9\x01\n\x18SetAnimalBoundaryRequest\x12\x14\n\x08panel_id\x18\x01 \x01(\x03\x42\x02\x18\x01\x12\x15\n\tdevice_id\x18\x02 \x01(\rB\x02\x18\x01\x12\x33\n\npoint_list\x18\x03 \x03(\x0b\x32\x1f.beam.PropertyBoundaryPointList\x12+\n\x06header\x18\x04 \x01(\x0b\x32\x1b.beam.SettingsRequestHeader\"=\n\x19SetAnimalBoundaryResponse\x12 \n\x08response\x18\x01 \x01(\x0b\x32\x0e.beam.Response\"\xaa\x01\n\x19SetPackageBoundaryRequest\x12\x14\n\x08panel_id\x18\x01 \x01(\x03\x42\x02\x18\x01\x12\x15\n\tdevice_id\x18\x02 \x01(\rB\x02\x18\x01\x12\x33\n\npoint_list\x18\x03 \x03(\x0b\x32\x1f.beam.PropertyBoundaryPointList\x12+\n\x06header\x18\x04 \x01(\x0b\x32\x1b.beam.SettingsRequestHeader\">\n\x1aSetPackageBoundaryResponse\x12 \n\x08response\x18\x01 \x01(\x0b\x32\x0e.beam.Response\"\xaa\x01\n\x19SetVehicleBoundaryRequest\x12\x14\n\x08panel_id\x18\x01 \x01(\x03\x42\x02\x18\x01\x12\x15\n\tdevice_id\x18\x02 \x01(\rB\x02\x18\x01\x12\x33\n\npoint_list\x18\x03 \x03(\x0b\x32\x1f.beam.PropertyBoundaryPointList\x12+\n\x06header\x18\x04 \x01(\x0b\x32\x1b.beam.SettingsRequestHeader\">\n\x1aSetVehicleBoundaryResponse\x12 \n\x08response\x18\x01 \x01(\x0b\x32\x0e.beam.Response\"\xa8\x01\n\x17SetDeterBoundaryRequest\x12\x14\n\x08panel_id\x18\x01 \x01(\x03\x42\x02\x18\x01\x12\x15\n\tdevice_id\x18\x02 \x01(\rB\x02\x18\x01\x12\x33\n\npoint_list\x18\x03 \x03(\x0b\x32\x1f.beam.PropertyBoundaryPointList\x12+\n\x06header\x18\x04 \x01(\x0b\x32\x1b.beam.SettingsRequestHeader\"<\n\x18SetDeterBoundaryResponse\x12 \n\x08response\x18\x01 \x01(\x0b\x32\x0e.beam.Response\"(\n\x14GetPanelLoginRequest\x12\x10\n\x08panel_id\x18\x01 \x01(\x03\"Y\n\x15GetPanelLoginResponse\x12 \n\x08response\x18\x01 \x01(\x0b\x32\x0e.beam.Response\x12\x0c\n\x04user\x18\x02 \x01(\t\x12\x10\n\x08password\x18\x03 \x01(\t\"W\n\x17SetCaptureClipOnRequest\x12+\n\x06header\x18\x01 \x01(\x0b\x32\x1b.beam.SettingsRequestHeader\x12\x0f\n\x07\x65nabled\x18\x02 \x01(\x08\"<\n\x18SetCaptureClipOnResponse\x12 \n\x08response\x18\x01 \x01(\x0b\x32\x0e.beam.Response\"W\n\x17SetRecordOnDeterRequest\x12\x10\n\x08panel_id\x18\x01 \x01(\x03\x12\x11\n\tdevice_id\x18\x02 \x01(\r\x12\x17\n\x0frecord_on_deter\x18\x03 \x01(\x08\"<\n\x18SetRecordOnDeterResponse\x12 \n\x08response\x18\x01 \x01(\x0b\x32\x0e.beam.Response\"a\n SetRecordOnPersonDetectedRequest\x12\x10\n\x08panel_id\x18\x01 \x01(\x03\x12\x11\n\tdevice_id\x18\x02 \x01(\r\x12\x18\n\x10record_on_person\x18\x03 \x01(\x08\"E\n!SetRecordOnPersonDetectedResponse\x12 \n\x08response\x18\x01 \x01(\x0b\x32\x0e.beam.Response\"c\n!SetRecordOnPackageDetectedRequest\x12\x10\n\x08panel_id\x18\x01 \x01(\x03\x12\x11\n\tdevice_id\x18\x02 \x01(\r\x12\x19\n\x11record_on_package\x18\x03 \x01(\x08\"F\n\"SetRecordOnPackageDetectedResponse\x12 \n\x08response\x18\x01 \x01(\x0b\x32\x0e.beam.Response\"a\n SetRecordOnLurkerDetectedRequest\x12\x10\n\x08panel_id\x18\x01 \x01(\x03\x12\x11\n\tdevice_id\x18\x02 \x01(\r\x12\x18\n\x10record_on_lurker\x18\x03 \x01(\x08\"E\n!SetRecordOnLurkerDetectedResponse\x12 \n\x08response\x18\x01 \x01(\x0b\x32\x0e.beam.Response\"a\n SetRecordOnAnimalDetectedRequest\x12\x10\n\x08panel_id\x18\x01 \x01(\x03\x12\x11\n\tdevice_id\x18\x02 \x01(\r\x12\x18\n\x10record_on_animal\x18\x03 \x01(\x08\"E\n!SetRecordOnAnimalDetectedResponse\x12 \n\x08response\x18\x01 \x01(\x0b\x32\x0e.beam.Response\"c\n!SetRecordOnVehicleDetectedRequest\x12\x10\n\x08panel_id\x18\x01 \x01(\x03\x12\x11\n\tdevice_id\x18\x02 \x01(\r\x12\x19\n\x11record_on_vehicle\x18\x03 \x01(\x08\"F\n\"SetRecordOnVehicleDetectedResponse\x12 \n\x08response\x18\x01 \x01(\x0b\x32\x0e.beam.Response\"t\n\x1aSetRecordForRegionsRequest\x12\x10\n\x08panel_id\x18\x01 \x01(\x03\x12\x11\n\tdevice_id\x18\x02 \x01(\r\x12\x31\n\x11record_for_region\x18\x03 \x01(\x0e\x32\x16.beam.RecordForRegions\"?\n\x1bSetRecordForRegionsResponse\x12 \n\x08response\x18\x01 \x01(\x0b\x32\x0e.beam.Response\"d\n\x1eSetAnalyticsSensitivityRequest\x12\x10\n\x08panel_id\x18\x01 \x01(\x03\x12\x11\n\tdevice_id\x18\x02 \x01(\r\x12\x1d\n\x15\x61nalytics_sensitivity\x18\x03 \x01(\x05\"C\n\x1fSetAnalyticsSensitivityResponse\x12 \n\x08response\x18\x01 \x01(\x0b\x32\x0e.beam.Response\"_\n\x13PreviewChimeRequest\x12\x10\n\x08panel_id\x18\x01 \x01(\x03\x12\x11\n\tdevice_id\x18\x02 \x01(\r\x12#\n\nchime_type\x18\x03 \x01(\x0e\x32\x0f.beam.ChimeType\"G\n#SetPackageDeliveryLocationsResponse\x12 \n\x08response\x18\x01 \x01(\x0b\x32\x0e.beam.Response\"\xbf\x01\n\"SetPackageDeliveryLocationsRequest\x12\x14\n\x08panel_id\x18\x01 \x01(\x03\x42\x02\x18\x01\x12\x15\n\tdevice_id\x18\x02 \x01(\rB\x02\x18\x01\x12?\n\x1apackage_delivery_locations\x18\x03 \x03(\x0b\x32\x1b.beam.PropertyBoundaryPoint\x12+\n\x06header\x18\x04 \x01(\x0b\x32\x1b.beam.SettingsRequestHeader\"8\n\x14PreviewChimeResponse\x12 \n\x08response\x18\x01 \x01(\x0b\x32\x0e.beam.Response\"v\n\x1aGetDeviceOnboardingRequest\x12\x14\n\x08panel_id\x18\x01 \x01(\x03\x42\x02\x18\x01\x12\x15\n\tdevice_id\x18\x02 \x01(\rB\x02\x18\x01\x12+\n\x06header\x18\x03 \x01(\x0b\x32\x1b.beam.SettingsRequestHeader\"\xdd\x04\n\x1bGetDeviceOnboardingResponse\x12 \n\x08response\x18\x01 \x01(\x0b\x32\x0e.beam.Response\x12\x19\n\x11property_boundary\x18\x02 \x01(\x08\x12\x15\n\rnotifications\x18\x03 \x01(\x08\x12\x13\n\x0b\x64\x65ter_intro\x18\x04 \x01(\x08\x12\x16\n\x0e\x64\x65ter_schedule\x18\x05 \x01(\x08\x12\x1e\n\x16\x64\x65ter_aggression_level\x18\x06 \x01(\x08\x12\x13\n\x0b\x63\x61mera_name\x18\x07 \x01(\x08\x12\x15\n\rcamera_rotate\x18\x08 \x01(\x08\x12\x18\n\x10\x61nalytics_opt_in\x18\t \x01(\x08\x12\x19\n\x11\x64oorbell_position\x18\n \x01(\x08\x12\"\n\x1apackage_delivery_locations\x18\x0b \x01(\x08\x12\x15\n\rpackage_watch\x18\x0c \x01(\x08\x12\x1c\n\x14property_boundary_v2\x18\r \x01(\x08\x12\x18\n\x10spotlight_splash\x18\x0e \x01(\x08\x12\x1d\n\x15spotlight_deter_intro\x18\x0f \x01(\x08\x12\"\n\x1aspotlight_default_settings\x18\x10 \x01(\x08\x12 \n\x18spotlight_deter_schedule\x18\x11 \x01(\x08\x12\x1d\n\x15spotlight_camera_name\x18\x12 \x01(\x08\x12\"\n\x1aspotlight_analytics_opt_in\x18\x13 \x01(\x08\x12!\n\x19spotlight_onboarding_done\x18\x14 \x01(\x08\"\xc6\x05\n\x1aSetDeviceOnboardingRequest\x12\x14\n\x08panel_id\x18\x01 \x01(\x03\x42\x02\x18\x01\x12\x15\n\tdevice_id\x18\x02 \x01(\rB\x02\x18\x01\x12\x1b\n\x11property_boundary\x18\x03 \x01(\x08H\x00\x12\x17\n\rnotifications\x18\x04 \x01(\x08H\x00\x12\x15\n\x0b\x64\x65ter_intro\x18\x05 \x01(\x08H\x00\x12\x18\n\x0e\x64\x65ter_schedule\x18\x06 \x01(\x08H\x00\x12 \n\x16\x64\x65ter_aggression_level\x18\x07 \x01(\x08H\x00\x12\x15\n\x0b\x63\x61mera_name\x18\x08 \x01(\x08H\x00\x12\x17\n\rcamera_rotate\x18\t \x01(\x08H\x00\x12\x1a\n\x10\x61nalytics_opt_in\x18\n \x01(\x08H\x00\x12\x1b\n\x11\x64oorbell_position\x18\x0b \x01(\x08H\x00\x12$\n\x1apackage_delivery_locations\x18\x0c \x01(\x08H\x00\x12\x17\n\rpackage_watch\x18\r \x01(\x08H\x00\x12\x1e\n\x14property_boundary_v2\x18\x0e \x01(\x08H\x00\x12\x1a\n\x10spotlight_splash\x18\x10 \x01(\x08H\x00\x12\x1f\n\x15spotlight_deter_intro\x18\x11 \x01(\x08H\x00\x12$\n\x1aspotlight_default_settings\x18\x12 \x01(\x08H\x00\x12\"\n\x18spotlight_deter_schedule\x18\x13 \x01(\x08H\x00\x12\x1f\n\x15spotlight_camera_name\x18\x14 \x01(\x08H\x00\x12$\n\x1aspotlight_analytics_opt_in\x18\x15 \x01(\x08H\x00\x12#\n\x19spotlight_onboarding_done\x18\x16 \x01(\x08H\x00\x12+\n\x06header\x18\x0f \x01(\x0b\x32\x1b.beam.SettingsRequestHeaderB\n\n\x08property\"?\n\x1bSetDeviceOnboardingResponse\x12 \n\x08response\x18\x01 \x01(\x0b\x32\x0e.beam.Response\"\xa9\x01\n\x1aSetDoorbellPositionRequest\x12\x14\n\x08panel_id\x18\x01 \x01(\x03\x42\x02\x18\x01\x12\x15\n\tdevice_id\x18\x02 \x01(\rB\x02\x18\x01\x12\x31\n\x11\x64oorbell_position\x18\x03 \x01(\x0e\x32\x16.beam.DoorbellPosition\x12+\n\x06header\x18\x04 \x01(\x0b\x32\x1b.beam.SettingsRequestHeader\"?\n\x1bSetDoorbellPositionResponse\x12 \n\x08response\x18\x01 \x01(\x0b\x32\x0e.beam.Response\"n\n\x1bSetPackageWatchStateRequest\x12\x10\n\x08panel_id\x18\x01 \x01(\x03\x12\x11\n\tdevice_id\x18\x02 \x01(\r\x12\x0f\n\x07on_duty\x18\x03 \x01(\x08\x12\x15\n\rend_timestamp\x18\x04 \x01(\x03:\x02\x18\x01\"D\n\x1cSetPackageWatchStateResponse\x12 \n\x08response\x18\x01 \x01(\x0b\x32\x0e.beam.Response:\x02\x18\x01\"M\n\x10\x44ynamicChimeInfo\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0b\n\x03url\x18\x03 \x01(\t\x12\x12\n\nsha256hash\x18\x04 \x01(\t\"o\n\x16\x44ynamicChimeBannerInfo\x12\x10\n\x08headline\x18\x01 \x01(\t\x12\x0f\n\x07subhead\x18\x02 \x01(\t\x12\x15\n\rMainAnimation\x18\x03 \x01(\t\x12\x1b\n\x13\x42\x61\x63kgroundAnimation\x18\x04 \x01(\t\"\xac\x01\n\x1a\x44ynamicChimeSplashPageInfo\x12\x11\n\tImage_iOS\x18\x01 \x01(\t\x12\x15\n\rImage_Android\x18\x02 \x01(\t\x12\x10\n\x08headline\x18\x03 \x01(\t\x12\x37\n\x07\x42ullets\x18\x04 \x03(\x0b\x32&.beam.DynamicChimeSplashPageBulletInfo\x12\x19\n\x11PrimaryButtonCopy\x18\x05 \x01(\t\"B\n DynamicChimeSplashPageBulletInfo\x12\x10\n\x08headline\x18\x01 \x01(\t\x12\x0c\n\x04\x62ody\x18\x02 \x01(\t\"\xfb\x02\n\x14\x44ynamicChimeCategory\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x36\n\x12\x61vailability_start\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x34\n\x10\x61vailability_end\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x1c\n\x14ui_availability_copy\x18\x05 \x01(\t\x12\x32\n\x12\x64ynamic_chime_info\x18\x06 \x03(\x0b\x32\x16.beam.DynamicChimeInfo\x12?\n\x19\x64ynamic_chime_banner_info\x18\x07 \x01(\x0b\x32\x1c.beam.DynamicChimeBannerInfo\x12H\n\x1e\x64ynamic_chime_splash_page_info\x18\x08 \x01(\x0b\x32 .beam.DynamicChimeSplashPageInfo\"\x80\x01\n\x17GetDynamicChimesRequest\x12\x10\n\x08panel_id\x18\x01 \x01(\x03\x12\x12\n\x08\x63hime_id\x18\x02 \x01(\tH\x00\x12\x1b\n\x11\x63hime_category_id\x18\x03 \x01(\tH\x00\x12\x1b\n\x13ignore_active_check\x18\x04 \x01(\x08\x42\x05\n\x03ids\"p\n\x18GetDynamicChimesResponse\x12 \n\x08response\x18\x01 \x01(\x0b\x32\x0e.beam.Response\x12\x32\n\x0e\x64ynamic_chimes\x18\x02 \x03(\x0b\x32\x1a.beam.DynamicChimeCategory\"\x8f\x01\n\x16SetDynamicChimeRequest\x12\x10\n\x08panel_id\x18\x01 \x01(\x03\x12\x11\n\tdevice_id\x18\x02 \x01(\r\x12\x19\n\x11\x63hime_category_id\x18\x03 \x01(\t\x12\x10\n\x08\x63hime_id\x18\x04 \x01(\t\x12#\n\nchime_type\x18\x05 \x01(\x0e\x32\x0f.beam.ChimeType\";\n\x17SetDynamicChimeResponse\x12 \n\x08response\x18\x01 \x01(\x0b\x32\x0e.beam.Response\"\xc9\x01\n\x12SetUserRoleRequest\x12+\n\x06header\x18\x01 \x01(\x0b\x32\x1b.beam.SettingsRequestHeader\x12\x14\n\x0ctargetUserId\x18\x02 \x01(\t\x12\x32\n\x07newRole\x18\x03 \x01(\x0e\x32!.beam.SetUserRoleRequest.UserRole\"<\n\x08UserRole\x12\x0b\n\x07NO_ROLE\x10\x00\x12\t\n\x05OWNER\x10\x01\x12\t\n\x05\x41\x44MIN\x10\x02\x12\r\n\tNON_ADMIN\x10\x03\"7\n\x13SetUserRoleResponse\x12 \n\x08response\x18\x01 \x01(\x0b\x32\x0e.beam.Response\"0\n\x04\x44\x61te\x12\x0c\n\x04year\x18\x01 \x01(\x05\x12\r\n\x05month\x18\x02 \x01(\x05\x12\x0b\n\x03\x64\x61y\x18\x03 \x01(\x05\"\x85\x01\n\x19GetClipSharingLinkRequest\x12+\n\x06header\x18\x01 \x01(\x0b\x32\x1b.beam.SettingsRequestHeader\x12 \n\x0chistory_date\x18\x02 \x01(\x0b\x32\n.beam.Date\x12\x19\n\x11history_record_id\x18\x03 \x01(\t\"Y\n\x1aGetClipSharingLinkResponse\x12 \n\x08response\x18\x01 \x01(\x0b\x32\x0e.beam.Response\x12\x19\n\x11\x63lip_sharing_link\x18\x02 \x01(\t\"\xb7\x02\n\x18ReportVideoFailedRequest\x12\x13\n\x0b\x63\x61mera_name\x18\x01 \x01(\t\x12\r\n\x05\x63ount\x18\x02 \x01(\x05\x12\x0c\n\x04\x64\x61te\x18\x03 \x01(\t\x12\x11\n\tdevice_id\x18\x04 \x01(\r\x12\x13\n\x0b\x64\x65vice_type\x18\x05 \x01(\t\x12\x11\n\tinterface\x18\x06 \x01(\t\x12\x18\n\x10mobile_device_id\x18\x07 \x01(\t\x12\x10\n\x08panel_id\x18\x08 \x01(\x03\x12\x1d\n\x15previous_stream_array\x18\t \x01(\t\x12\x0e\n\x06reason\x18\n \x01(\t\x12\x0f\n\x07session\x18\x0b \x01(\t\x12\x0b\n\x03url\x18\x0c \x01(\t\x12\x0b\n\x03\x61pp\x18\r \x01(\t\x12\x13\n\x0bstream_name\x18\x0e \x01(\t\x12\x13\n\x0b\x61pp_version\x18\x0f \x01(\t\"Q\n\x19ReportVideoFailedResponse\x12 \n\x08response\x18\x01 \x01(\x0b\x32\x0e.beam.Response\x12\x12\n\nrequest_id\x18\x02 \x01(\t\"/\n\x1bPanelKillWiFiNetworkRequest\x12\x10\n\x08panel_id\x18\x01 \x01(\x03\"G\n\x1bPanelRefreshSSIDListRequest\x12\x10\n\x08panel_id\x18\x01 \x01(\x03\x12\x16\n\x0e\x66orWiFiConnect\x18\x02 \x01(\x08\"B\n\x1eStartCameraWifiConnectResponse\x12 \n\x08response\x18\x01 \x01(\x0b\x32\x0e.beam.Response\"J\n\x1dStartCameraWifiConnectRequest\x12\x10\n\x08panel_id\x18\x01 \x01(\x03\x12\x17\n\x0f\x63\x61mera_ap_ssids\x18\x02 \x03(\t\"m\n\x15\x41\x64\x64\x43\x61meraToHubRequest\x12\x10\n\x08panel_id\x18\x01 \x01(\x03\x12\x13\n\x0b\x63\x61mera_type\x18\x02 \x01(\t\x12\x0c\n\x04uuid\x18\x03 \x01(\t\x12\x12\n\nip_address\x18\x04 \x01(\t\x12\x0b\n\x03urn\x18\x05 \x01(\t\"\x85\x01\n\x0f\x41\x63\x63\x65ssPointInfo\x12\x0f\n\x07\x63hannel\x18\x01 \x01(\r\x12\x0c\n\x04ssid\x18\x02 \x01(\t\x12\x10\n\x08mac_addr\x18\x03 \x01(\t\x12\x18\n\x10\x65ncryption_types\x18\x04 \x01(\t\x12\x16\n\x0esignal_percent\x18\x05 \x01(\x05\x12\x0f\n\x07unknown\x18\x06 \x01(\x05\"9\n\x08Response\x12-\n\ttimestamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"S\n\x0fSoftwareVersion\x12\r\n\x05major\x18\x01 \x01(\x05\x12\r\n\x05minor\x18\x02 \x01(\x05\x12\x13\n\x0bmaintenance\x18\x03 \x01(\x05\x12\r\n\x05\x62uild\x18\x04 \x01(\x05\"6\n\x10TypeCapabilities\x12\x0c\n\x04type\x18\x01 \x01(\r\x12\x14\n\x0c\x63\x61pabilities\x18\x02 \x03(\r\"?\n\x0c\x43\x61pabilities\x12/\n\x0ftype_capability\x18\x01 \x03(\x0b\x32\x16.beam.TypeCapabilities\"\xc3\x02\n\rTechnicalInfo\x12\x0e\n\x06status\x18\x01 \x01(\x08\x12\x17\n\x0fsignal_strength\x18\x03 \x01(\x02\x12\x12\n\nip_address\x18\x04 \x01(\t\x12\x0f\n\x07\x41P_SSID\x18\x06 \x01(\t\x12\x18\n\x10software_version\x18\x07 \x01(\t\x12\x19\n\x11\x61nalytics_version\x18\x08 \x01(\t\x12\x13\n\x0b\x61\x63tual_type\x18\t \x01(\t\x12\x13\n\x0bmac_address\x18\n \x01(\t\x12\x33\n\x0b\x61udio_codec\x18\x0b \x01(\x0e\x32\x1e.beam.TechnicalInfo.AudioCodec\x12\x19\n\x11\x61udio_sample_rate\x18\x0c \x01(\x05\"5\n\nAudioCodec\x12\x0b\n\x07INVALID\x10\x00\x12\x10\n\x0cMU_LAW_G_711\x10\x01\x12\x08\n\x04OPUS\x10\x02\"\x8d\x01\n\x0f\x44\x65tectionWindow\x12\x10\n\x08origin_x\x18\x01 \x01(\x02\x12\x10\n\x08origin_y\x18\x02 \x01(\x02\x12\r\n\x05width\x18\x03 \x01(\x02\x12\x0e\n\x06height\x18\x04 \x01(\x02\x12\x13\n\x0bsensitivity\x18\x05 \x01(\x02\x12\x13\n\x0bobject_size\x18\x06 \x01(\x02\x12\r\n\x05index\x18\x07 \x01(\x05\"H\n\x19PropertyBoundaryPointList\x12+\n\x06points\x18\x01 \x03(\x0b\x32\x1b.beam.PropertyBoundaryPoint\"-\n\x15PropertyBoundaryPoint\x12\t\n\x01x\x18\x01 \x01(\x02\x12\t\n\x01y\x18\x02 \x01(\x02\"\xa2\x01\n\rDeterSchedule\x12\x0b\n\x03sun\x18\x01 \x01(\x08\x12\x0b\n\x03mon\x18\x02 \x01(\x08\x12\x0b\n\x03tue\x18\x03 \x01(\x08\x12\x0b\n\x03wed\x18\x04 \x01(\x08\x12\x0b\n\x03thu\x18\x05 \x01(\x08\x12\x0b\n\x03\x66ri\x18\x06 \x01(\x08\x12\x0b\n\x03sat\x18\x07 \x01(\x08\x12\x1b\n\x13local_start_minutes\x18\x08 \x01(\r\x12\x19\n\x11local_end_minutes\x18\t \x01(\r\"S\n\x16\x43\x61meraThumbnailRequest\x12\x10\n\x08panel_id\x18\x01 \x01(\x03\x12\x11\n\tdevice_id\x18\x02 \x01(\r\x12\x14\n\x0cpartition_id\x18\x03 \x01(\r\";\n\x17\x43\x61meraThumbnailResponse\x12 \n\x08response\x18\x01 \x01(\x0b\x32\x0e.beam.Response\"E\n\x13SystemRequestHeader\x12\x11\n\tsystem_id\x18\x01 \x01(\x03\x12\x1b\n\x13is_smarthome_system\x18\x02 \x01(\x08\"\x94\x01\n\x18GetHistoryClipURLRequest\x12)\n\x06header\x18\x01 \x01(\x0b\x32\x19.beam.SystemRequestHeader\x12\x19\n\x11history_record_id\x18\x02 \x01(\t\x12 \n\x0chistory_date\x18\x03 \x01(\x0b\x32\n.beam.Date\x12\x10\n\x08\x64ownload\x18\x04 \x01(\x08\";\n\x1eGetLegacyHistoryClipURLRequest\x12\x19\n\x11history_record_id\x18\x01 \x01(\t\"O\n\x19GetHistoryClipURLResponse\x12 \n\x08response\x18\x01 \x01(\x0b\x32\x0e.beam.Response\x12\x10\n\x08\x63lip_url\x18\x02 \x01(\t\"I\n\x13\x41ssociateDvrRequest\x12\x10\n\x08panel_id\x18\x01 \x01(\x03\x12 \n\x18space_monkey_hardware_id\x18\x02 \x01(\t\".\n\x14\x41ssociateDvrResponse\x12\x16\n\x0e\x64vr_service_id\x18\x02 \x01(\t\"\xaa\x02\n\x18SpotlightCalibrationData\x12H\n\x10\x63\x61libration_type\x18\x01 \x01(\x0e\x32..beam.SpotlightCalibrationData.CalibrationType\x12\x36\n\x05zones\x18\x02 \x03(\x0b\x32\'.beam.SpotlightCalibrationData.ZoneData\x1a\x41\n\x08ZoneData\x12\x0f\n\x07zone_id\x18\x01 \x01(\r\x12\t\n\x01x\x18\x02 \x01(\x02\x12\t\n\x01y\x18\x03 \x01(\x02\x12\x0e\n\x06in_fov\x18\x04 \x01(\x08\"I\n\x0f\x43\x61librationType\x12\x19\n\x15\x43\x41LIBRATION_TYPE_AUTO\x10\x00\x12\x1b\n\x17\x43\x41LIBRATION_TYPE_MANUAL\x10\x01\"\x87\x01\n\x1eSetSpotlightCalibrationRequest\x12+\n\x06header\x18\x01 \x01(\x0b\x32\x1b.beam.SettingsRequestHeader\x12\x38\n\x10\x63\x61libration_data\x18\x02 \x01(\x0b\x32\x1e.beam.SpotlightCalibrationData\"C\n\x1fSetSpotlightCalibrationResponse\x12 \n\x08response\x18\x01 \x01(\x0b\x32\x0e.beam.Response\"g\n\x18SetSpotlightZonesRequest\x12+\n\x06header\x18\x01 \x01(\x0b\x32\x1b.beam.SettingsRequestHeader\x12\x1e\n\x16\x65nabled_zones_bitfield\x18\x02 \x01(\r\"=\n\x19SetSpotlightZonesResponse\x12 \n\x08response\x18\x01 \x01(\x0b\x32\x0e.beam.Response\"v\n(SetSpotlightLightOnPersonDetectedRequest\x12+\n\x06header\x18\x01 \x01(\x0b\x32\x1b.beam.SettingsRequestHeader\x12\x1d\n\x15LightOnPersonDetected\x18\x02 \x01(\x08\"M\n)SetSpotlightLightOnPersonDetectedResponse\x12 \n\x08response\x18\x01 \x01(\x0b\x32\x0e.beam.Response\"h\n\x1dSetSpotlightBrightnessRequest\x12+\n\x06header\x18\x01 \x01(\x0b\x32\x1b.beam.SettingsRequestHeader\x12\x1a\n\x12\x62rightness_percent\x18\x02 \x01(\x02\"B\n\x1eSetSpotlightBrightnessResponse\x12 \n\x08response\x18\x01 \x01(\x0b\x32\x0e.beam.Response\"]\n\x17ToggleFloodlightRequest\x12+\n\x06header\x18\x01 \x01(\x0b\x32\x1b.beam.SettingsRequestHeader\x12\x15\n\rfloodlight_on\x18\x02 \x01(\x08\"<\n\x18ToggleFloodlightResponse\x12 \n\x08response\x18\x01 \x01(\x0b\x32\x0e.beam.Response\"h\n$SetSpotlightOnSunsetToSunriseRequest\x12+\n\x06header\x18\x01 \x01(\x0b\x32\x1b.beam.SettingsRequestHeader\x12\x0f\n\x07\x65nabled\x18\x02 \x01(\x08:\x02\x18\x01\"M\n%SetSpotlightOnSunsetToSunriseResponse\x12 \n\x08response\x18\x01 \x01(\x0b\x32\x0e.beam.Response:\x02\x18\x01\"]\n\x1dSetSpotlightNightLightRequest\x12+\n\x06header\x18\x01 \x01(\x0b\x32\x1b.beam.SettingsRequestHeader\x12\x0f\n\x07\x65nabled\x18\x02 \x01(\x08\"B\n\x1eSetSpotlightNightLightResponse\x12 \n\x08response\x18\x01 \x01(\x0b\x32\x0e.beam.Response\"X\n\x11\x42\x65\x61mPortalCommand\x12\x0c\n\x04uuid\x18\x01 \x01(\t\x12*\n setEnabledSpotlightZonesBitfield\x18\x02 \x01(\rH\x00\x42\t\n\x07\x63ommand\"\x92\x01\n\x10LightingBehavior\x12\x31\n\x08\x62\x65havior\x18\x02 \x01(\x0e\x32\x1f.beam.LightingBehavior.Behavior\"K\n\x08\x42\x65havior\x12\x07\n\x03OFF\x10\x00\x12\t\n\x05\x46LOOD\x10\x01\x12\t\n\x05TRACK\x10\x02\x12\x08\n\x04WAVE\x10\x03\x12\n\n\x06\x43IRCLE\x10\x04\x12\n\n\x06STROBE\x10\x65\"\x80\x01\n\x1fSetDeterLightingBehaviorRequest\x12+\n\x06header\x18\x01 \x01(\x0b\x32\x1b.beam.SettingsRequestHeader\x12\x30\n\x10lightingBehavior\x18\x02 \x01(\x0b\x32\x16.beam.LightingBehavior\"D\n SetDeterLightingBehaviorResponse\x12 \n\x08response\x18\x01 \x01(\x0b\x32\x0e.beam.Response\"X\n\x19SetSpotlightFollowRequest\x12+\n\x06header\x18\x01 \x01(\x0b\x32\x1b.beam.SettingsRequestHeader\x12\x0e\n\x06\x66ollow\x18\x02 \x01(\x08\">\n\x1aSetSpotlightFollowResponse\x12 \n\x08response\x18\x01 \x01(\x0b\x32\x0e.beam.Response*\xcf\x02\n\x11\x44\x65terScheduleType\x12\n\n\x06\x41LWAYS\x10\x00\x12\r\n\tSCHEDULED\x10\x01\x12\t\n\x05\x41RMED\x10\x02\x12\x0f\n\x0bSCHTYPENONE\x10\x03\x12\t\n\x05NEVER\x10\x04\x12\x11\n\rUSER_OVERRIDE\x10\x05\x12\x11\n\rCUSTOM_ACTION\x10\x06\x12\x18\n\x14UNKNOWN_OBJECT_DETER\x10\x07\x12\x11\n\rPACKAGE_DETER\x10\x08\x12\x17\n\x13PACKAGE_MOVED_DETER\x10\t\x12\x10\n\x0cPERSON_DETER\x10\n\x12\x10\n\x0cLURKER_DETER\x10\x0b\x12\x11\n\rVEHICLE_DETER\x10\x0c\x12\x10\n\x0c\x41NIMAL_DETER\x10\r\x12\n\n\x06SNOOZE\x10\x0e\x12\x1c\n\x18PACKAGE_APPROACHED_DETER\x10\x0f\x12\x19\n\x15VEHICLE_LEAVING_DETER\x10\x10*m\n\x14\x44\x65terAggressionLevel\x12\x07\n\x03ONE\x10\x00\x12\x07\n\x03TWO\x10\x01\x12\t\n\x05THREE\x10\x02\x12\x08\n\x04\x46OUR\x10\x03\x12\x10\n\x0c\x41GGLEVELNONE\x10\x04\x12\x08\n\x04\x46IVE\x10\x05\x12\x07\n\x03SIX\x10\x06\x12\t\n\x05SEVEN\x10\x07*&\n\x0f\x44\x65terLightColor\x12\x07\n\x03RED\x10\x00\x12\n\n\x06YELLOW\x10\x01*5\n\x11\x44\x65terLightPattern\x12\t\n\x05SOLID\x10\x00\x12\t\n\x05\x46LASH\x10\x01\x12\n\n\x06\x42REATH\x10\x02*O\n\x0cVideoQuality\x12\x0b\n\x07VQ_ZERO\x10\x00\x12\x07\n\x03LOW\x10\x01\x12\x08\n\x04\x46\x41IR\x10\x02\x12\n\n\x06MEDIUM\x10\x03\x12\x08\n\x04GOOD\x10\x04\x12\t\n\x05GREAT\x10\x05*\xa2\x01\n\rDoorbellChime\x12\x0b\n\x07\x44\x43_NONE\x10\x00\x12\x0f\n\x0bTRADITIONAL\x10\x01\x12\x0c\n\x08\x45LEVATOR\x10\x02\x12\n\n\x06MELODY\x10\x08\x12\t\n\x05\x42\x45LLS\x10\x11\x12\n\n\x06MODERN\x10\x12\x12\r\n\tELEVATOR2\x10\x13\x12\x0b\n\x07MELODY2\x10\x14\x12\x10\n\x0cTRADITIONAL2\x10\x15\x12\x14\n\x10\x44OORBELL_DYNAMIC\x10\x1a*\xa2\x01\n\x0cVisitorChime\x12\x0b\n\x07VC_NONE\x10\x00\x12\x0b\n\x07INSIGHT\x10\x03\x12\x0e\n\nLOW_DOUBLE\x10\x04\x12\t\n\x05PIANO\x10\x05\x12\x0f\n\x0bHIGH_DOUBLE\x10\x07\x12\r\n\tDINGALING\x10\x0c\x12\t\n\x05\x44ROPS\x10\r\x12\x06\n\x02HI\x10\x0e\x12\x0b\n\x07SUCCESS\x10\x0f\x12\x08\n\x04WAVE\x10\x10\x12\x13\n\x0fVISITOR_DYNAMIC\x10\x1a*\xe1\x01\n\x0cPackageChime\x12\x0b\n\x07PC_NONE\x10\x00\x12\x13\n\x0fPACKAGE_DYNAMIC\x10\x1a\x12\t\n\x05\x41LERT\x10\x33\x12\x0c\n\x08\x46RIENDLY\x10\x34\x12\t\n\x05HELLO\x10\x35\x12\t\n\x05SCALE\x10\x36\x12\x0b\n\x07WHISTLE\x10\x37\x12\x0e\n\nLIGHT_ONLY\x10\x38\x12\r\n\tRECORDING\x10\x39\x12\x08\n\x04PC_8\x10:\x12\x08\n\x04PC_9\x10;\x12\t\n\x05PC_10\x10<\x12\t\n\x05PC_11\x10=\x12\t\n\x05PC_12\x10>\x12\t\n\x05PC_13\x10?\x12\t\n\x05PC_14\x10@\x12\t\n\x05PC_15\x10\x41*e\n\x10RecordForRegions\x12\x1d\n\x19RECORD_FOR_REGIONS_NOTSET\x10\x00\x12\x17\n\x13RECORD_FOR_PROPERTY\x10\x01\x12\x19\n\x15RECORD_FOR_EVERYWHERE\x10\x02*K\n\tChimeType\x12\x16\n\x12INVALID_CHIME_TYPE\x10\x00\x12\x0c\n\x08\x44OORBELL\x10\x01\x12\x0b\n\x07VISITOR\x10\x02\x12\x0b\n\x07PACKAGE\x10\x03*[\n\x10\x44oorbellPosition\x12\t\n\x05UNSET\x10\x00\x12\r\n\tLEFT_SIDE\x10\x01\x12\x0e\n\nRIGHT_SIDE\x10\x02\x12\r\n\tLEFT_WALL\x10\x03\x12\x0e\n\nRIGHT_WALL\x10\x04*\xaf\x01\n\rSpotlightMode\x12\x16\n\x12SPOTLIGHT_MODE_OFF\x10\x00\x12\x18\n\x14SPOTLIGHT_MODE_FLOOD\x10\x01\x12\x1c\n\x18SPOTLIGHT_MODE_CALIBRATE\x10\x02\x12\x18\n\x14SPOTLIGHT_MODE_TRACK\x10\x03\x12\x18\n\x14SPOTLIGHT_MODE_DETER\x10\x04\x12\x1a\n\x16SPOTLIGHT_MODE_STARTUP\x10\x05*\xa8\x02\n\x0fSpotlightStatus\x12\x1c\n\x18SPOTLIGHT_STATUS_SUCCESS\x10\x00\x12\"\n\x1eSPOTLIGHT_STATUS_UNKNOWN_ERROR\x10\x01\x12 \n\x1cSPOTLIGHT_STATUS_NO_HARDWARE\x10\x02\x12\x1f\n\x1bSPOTLIGHT_STATUS_BAD_DEVICE\x10\x03\x12!\n\x1dSPOTLIGHT_STATUS_NO_LED_POWER\x10\x04\x12\"\n\x1eSPOTLIGHT_STATUS_NO_HW_VERSION\x10\x05\x12#\n\x1fSPOTLIGHT_STATUS_NO_TEMPERATURE\x10\x06\x12$\n SPOTLIGHT_STATUS_INVALID_COMMAND\x10\x07\x32\xdb\x43\n\x04\x42\x65\x61m\x12\x30\n\x04Ping\x12\x16.google.protobuf.Empty\x1a\x0e.beam.Response\"\x00\x12J\n\rSetDeviceName\x12\x1a.beam.SetDeviceNameRequest\x1a\x1b.beam.SetDeviceNameResponse\"\x00\x12\x65\n\x16GetCameraTechnicalInfo\x12#.beam.GetCameraTechnicalInfoRequest\x1a$.beam.GetCameraTechnicalInfoResponse\"\x00\x12V\n\x11GetCameraSettings\x12\x1e.beam.GetCameraSettingsRequest\x1a\x1f.beam.GetCameraSettingsResponse\"\x00\x12S\n\x10GetPanelSettings\x12\x1d.beam.GetPanelSettingsRequest\x1a\x1e.beam.GetPanelSettingsResponse\"\x00\x12_\n\x14SetCameraPrivacyMode\x12!.beam.SetCameraPrivacyModeRequest\x1a\".beam.SetCameraPrivacyModeResponse\"\x00\x12V\n\x11\x41\x64justCameraToXyz\x12\x1e.beam.AdjustCameraToXyzRequest\x1a\x1f.beam.AdjustCameraToXyzResponse\"\x00\x12k\n\x18SetCameraPlaybackEnabled\x12%.beam.SetCameraPlaybackEnabledRequest\x1a&.beam.SetCameraPlaybackEnabledResponse\"\x00\x12\\\n\x13SetDetectionWindows\x12 .beam.SetDetectionWindowsRequest\x1a!.beam.SetDetectionWindowsResponse\"\x00\x12M\n\x0eSetChimeVolume\x12\x1b.beam.SetChimeVolumeRequest\x1a\x1c.beam.SetChimeVolumeResponse\"\x00\x12G\n\x0cSetChimeMute\x12\x19.beam.SetChimeMuteRequest\x1a\x1a.beam.SetChimeMuteResponse\"\x00\x12P\n\x0fSetVideoQuality\x12\x1c.beam.SetVideoQualityRequest\x1a\x1d.beam.SetVideoQualityResponse\"\x00\x12M\n\x0eSetNightVision\x12\x1b.beam.SetNightVisionRequest\x1a\x1c.beam.SetNightVisionResponse\"\x00\x12;\n\x08SetIRLED\x12\x15.beam.SetIRLEDRequest\x1a\x16.beam.SetIRLEDResponse\"\x00\x12M\n\x0eSetRotateImage\x12\x1b.beam.SetRotateImageRequest\x1a\x1c.beam.SetRotateImageResponse\"\x00\x12P\n\x0fSetMaintainZoom\x12\x1c.beam.SetMaintainZoomRequest\x1a\x1d.beam.SetMaintainZoomResponse\"\x00\x12M\n\x0eSetStatusLight\x12\x1b.beam.SetStatusLightRequest\x1a\x1c.beam.SetStatusLightResponse\"\x00\x12V\n\x11SetAudioRecording\x12\x1e.beam.SetAudioRecordingRequest\x1a\x1f.beam.SetAudioRecordingResponse\"\x00\x12S\n\x10SetDoorbellChime\x12\x1d.beam.SetDoorbellChimeRequest\x1a\x1e.beam.SetDoorbellChimeResponse\"\x00\x12S\n\x10SetDoorbellMuted\x12\x1d.beam.SetDoorbellMutedRequest\x1a\x1e.beam.SetDoorbellMutedResponse\"\x00\x12P\n\x0fSetVisitorChime\x12\x1c.beam.SetVisitorChimeRequest\x1a\x1d.beam.SetVisitorChimeResponse\"\x00\x12P\n\x0fSetPackageChime\x12\x1c.beam.SetPackageChimeRequest\x1a\x1d.beam.SetPackageChimeResponse\"\x00\x12z\n\x1dSetUseAsDoorbellChimeExtender\x12*.beam.SetUseAsDoorbellChimeExtenderRequest\x1a+.beam.SetUseAsDoorbellChimeExtenderResponse\"\x00\x12M\n\x0eSetExtendSiren\x12\x1b.beam.SetExtendSirenRequest\x1a\x1c.beam.SetExtendSirenResponse\"\x00\x12G\n\x0cSetQuietMode\x12\x19.beam.SetQuietModeRequest\x1a\x1a.beam.SetQuietModeResponse\"\x00\x12V\n\x11GetAnalyticsOptIn\x12\x1e.beam.GetAnalyticsOptInRequest\x1a\x1f.beam.GetAnalyticsOptInResponse\"\x00\x12V\n\x11SetAnalyticsOptIn\x12\x1e.beam.SetAnalyticsOptInRequest\x1a\x1f.beam.SetAnalyticsOptInResponse\"\x00\x12R\n\x19SetNotifyOnPersonDetected\x12\x18.beam.SetNotifyOnRequest\x1a\x19.beam.SetNotifyOnResponse\"\x00\x12R\n\x19SetNotifyOnLurkerDetected\x12\x18.beam.SetNotifyOnRequest\x1a\x19.beam.SetNotifyOnResponse\"\x00\x12O\n\x16SetNotifyOnPackageSeen\x12\x18.beam.SetNotifyOnRequest\x1a\x19.beam.SetNotifyOnResponse\"\x00\x12P\n\x17SetNotifyOnPackageMoved\x12\x18.beam.SetNotifyOnRequest\x1a\x19.beam.SetNotifyOnResponse\"\x00\x12O\n\x16SetNotifyOnVehicleSeen\x12\x18.beam.SetNotifyOnRequest\x1a\x19.beam.SetNotifyOnResponse\"\x00\x12N\n\x15SetNotifyOnAnimalSeen\x12\x18.beam.SetNotifyOnRequest\x1a\x19.beam.SetNotifyOnResponse\"\x00\x12I\n\x10SetNotifyOnDeter\x12\x18.beam.SetNotifyOnRequest\x1a\x19.beam.SetNotifyOnResponse\"\x00\x12Q\n\x18SetNotifyOnDoorbellPress\x12\x18.beam.SetNotifyOnRequest\x1a\x19.beam.SetNotifyOnResponse\"\x00\x12R\n\x19SetNotifyOnVehicleLeaving\x12\x18.beam.SetNotifyOnRequest\x1a\x19.beam.SetNotifyOnResponse\"\x00\x12P\n\x0fRestoreDefaults\x12\x1c.beam.RestoreDefaultsRequest\x1a\x1d.beam.RestoreDefaultsResponse\"\x00\x12G\n\x0cRebootCamera\x12\x19.beam.RebootCameraRequest\x1a\x1a.beam.RebootCameraResponse\"\x00\x12P\n\x0f\x44\x65leteAllEvents\x12\x1c.beam.DeleteAllEventsRequest\x1a\x1d.beam.DeleteAllEventsResponse\"\x00\x12G\n\x0c\x44\x65leteCamera\x12\x19.beam.DeleteCameraRequest\x1a\x1a.beam.DeleteCameraResponse\"\x00\x12Y\n\x12SetCameraListOrder\x12\x1f.beam.SetCameraListOrderRequest\x1a .beam.SetCameraListOrderResponse\"\x00\x12M\n\x0eSetLurkerDeter\x12\x1b.beam.SetLurkerDeterRequest\x1a\x1c.beam.SetLurkerDeterResponse\"\x00\x12_\n\x14SetSmartSentrySnooze\x12!.beam.SetSmartSentrySnoozeRequest\x1a\".beam.SetSmartSentrySnoozeResponse\"\x00\x12P\n\x0fSetPackageWatch\x12\x1c.beam.SetPackageWatchRequest\x1a\x1d.beam.SetPackageWatchResponse\"\x00\x12V\n\x11SetAnimalBoundary\x12\x1e.beam.SetAnimalBoundaryRequest\x1a\x1f.beam.SetAnimalBoundaryResponse\"\x00\x12Y\n\x12SetPackageBoundary\x12\x1f.beam.SetPackageBoundaryRequest\x1a .beam.SetPackageBoundaryResponse\"\x00\x12Y\n\x12SetVehicleBoundary\x12\x1f.beam.SetVehicleBoundaryRequest\x1a .beam.SetVehicleBoundaryResponse\"\x00\x12\\\n\x13SetPropertyBoundary\x12 .beam.SetPropertyBoundaryRequest\x1a!.beam.SetPropertyBoundaryResponse\"\x00\x12S\n\x10SetDeterBoundary\x12\x1d.beam.SetDeterBoundaryRequest\x1a\x1e.beam.SetDeterBoundaryResponse\"\x00\x12S\n\x10SetDeterSchedule\x12\x1d.beam.SetDeterScheduleRequest\x1a\x1e.beam.SetDeterScheduleResponse\"\x00\x12Y\n\x12SetDeterScheduleV2\x12\x1f.beam.SetDeterScheduleV2Request\x1a .beam.SetDeterScheduleV2Response\"\x00\x12h\n\x17SetDeterAggressionLevel\x12$.beam.SetDeterAggressionLevelRequest\x1a%.beam.SetDeterAggressionLevelResponse\"\x00\x12Y\n\x12SetDeterLightColor\x12\x1f.beam.SetDeterLightColorRequest\x1a .beam.SetDeterLightColorResponse\"\x00\x12_\n\x14SetDeterLightPattern\x12!.beam.SetDeterLightPatternRequest\x1a\".beam.SetDeterLightPatternResponse\"\x00\x12S\n\x10SetDeterOverride\x12\x1d.beam.SetDeterOverrideRequest\x1a\x1e.beam.SetDeterOverrideResponse\"\x00\x12V\n\x11SetLingerDuration\x12\x1e.beam.SetLingerDurationRequest\x1a\x1f.beam.SetLingerDurationResponse\"\x00\x12J\n\rGetPanelLogin\x12\x1a.beam.GetPanelLoginRequest\x1a\x1b.beam.GetPanelLoginResponse\"\x00\x12\\\n\x13GetDeviceOnboarding\x12 .beam.GetDeviceOnboardingRequest\x1a!.beam.GetDeviceOnboardingResponse\"\x00\x12\\\n\x13SetDeviceOnboarding\x12 .beam.SetDeviceOnboardingRequest\x1a!.beam.SetDeviceOnboardingResponse\"\x00\x12Y\n\x16SetCaptureClipOnMotion\x12\x1d.beam.SetCaptureClipOnRequest\x1a\x1e.beam.SetCaptureClipOnResponse\"\x00\x12_\n\x1cSetCaptureClipOnDoorbellRing\x12\x1d.beam.SetCaptureClipOnRequest\x1a\x1e.beam.SetCaptureClipOnResponse\"\x00\x12Z\n\x17SetCaptureClipOnVisitor\x12\x1d.beam.SetCaptureClipOnRequest\x1a\x1e.beam.SetCaptureClipOnResponse\"\x00\x12S\n\x10SetRecordOnDeter\x12\x1d.beam.SetRecordOnDeterRequest\x1a\x1e.beam.SetRecordOnDeterResponse\"\x00\x12n\n\x19SetRecordOnPersonDetected\x12&.beam.SetRecordOnPersonDetectedRequest\x1a\'.beam.SetRecordOnPersonDetectedResponse\"\x00\x12q\n\x1aSetRecordOnPackageDetected\x12\'.beam.SetRecordOnPackageDetectedRequest\x1a(.beam.SetRecordOnPackageDetectedResponse\"\x00\x12n\n\x19SetRecordOnLurkerDetected\x12&.beam.SetRecordOnLurkerDetectedRequest\x1a\'.beam.SetRecordOnLurkerDetectedResponse\"\x00\x12n\n\x19SetRecordOnAnimalDetected\x12&.beam.SetRecordOnAnimalDetectedRequest\x1a\'.beam.SetRecordOnAnimalDetectedResponse\"\x00\x12q\n\x1aSetRecordOnVehicleDetected\x12\'.beam.SetRecordOnVehicleDetectedRequest\x1a(.beam.SetRecordOnVehicleDetectedResponse\"\x00\x12\\\n\x13SetRecordForRegions\x12 .beam.SetRecordForRegionsRequest\x1a!.beam.SetRecordForRegionsResponse\"\x00\x12h\n\x17SetAnalyticsSensitivity\x12$.beam.SetAnalyticsSensitivityRequest\x1a%.beam.SetAnalyticsSensitivityResponse\"\x00\x12G\n\x0cPreviewChime\x12\x19.beam.PreviewChimeRequest\x1a\x1a.beam.PreviewChimeResponse\"\x00\x12t\n\x1bSetPackageDeliveryLocations\x12(.beam.SetPackageDeliveryLocationsRequest\x1a).beam.SetPackageDeliveryLocationsResponse\"\x00\x12\\\n\x13SetDoorbellPosition\x12 .beam.SetDoorbellPositionRequest\x1a!.beam.SetDoorbellPositionResponse\"\x00\x12S\n\x10GetDynamicChimes\x12\x1d.beam.GetDynamicChimesRequest\x1a\x1e.beam.GetDynamicChimesResponse\"\x00\x12P\n\x0fSetDynamicChime\x12\x1c.beam.SetDynamicChimeRequest\x1a\x1d.beam.SetDynamicChimeResponse\"\x00\x12\x62\n\x14SetPackageWatchState\x12!.beam.SetPackageWatchStateRequest\x1a\".beam.SetPackageWatchStateResponse\"\x03\x88\x02\x01\x12\x44\n\x0bSetUserRole\x12\x18.beam.SetUserRoleRequest\x1a\x19.beam.SetUserRoleResponse\"\x00\x12Y\n\x12GetClipSharingLink\x12\x1f.beam.GetClipSharingLinkRequest\x1a .beam.GetClipSharingLinkResponse\"\x00\x12K\n\x14PanelKillWiFiNetwork\x12!.beam.PanelKillWiFiNetworkRequest\x1a\x0e.beam.Response\"\x00\x12K\n\x14PanelRefreshSSIDList\x12!.beam.PanelRefreshSSIDListRequest\x1a\x0e.beam.Response\"\x00\x12\x65\n\x16StartCameraWifiConnect\x12#.beam.StartCameraWifiConnectRequest\x1a$.beam.StartCameraWifiConnectResponse\"\x00\x12?\n\x0e\x41\x64\x64\x43\x61meraToHub\x12\x1b.beam.AddCameraToHubRequest\x1a\x0e.beam.Response\"\x00\x12V\n\x11ReportVideoFailed\x12\x1e.beam.ReportVideoFailedRequest\x1a\x1f.beam.ReportVideoFailedResponse\"\x00\x12W\n\x16RequestCameraThumbnail\x12\x1c.beam.CameraThumbnailRequest\x1a\x1d.beam.CameraThumbnailResponse\"\x00\x12O\n\x15GetCameraThumbnailUrl\x12\x1c.beam.CameraThumbnailRequest\x1a\x16.google.protobuf.Empty\"\x00\x12V\n\x11GetHistoryClipURL\x12\x1e.beam.GetHistoryClipURLRequest\x1a\x1f.beam.GetHistoryClipURLResponse\"\x00\x12\x62\n\x17GetLegacyHistoryClipURL\x12$.beam.GetLegacyHistoryClipURLRequest\x1a\x1f.beam.GetHistoryClipURLResponse\"\x00\x12G\n\x0c\x41ssociateDvr\x12\x19.beam.AssociateDvrRequest\x1a\x1a.beam.AssociateDvrResponse\"\x00\x12V\n\x11SetSpotlightZones\x12\x1e.beam.SetSpotlightZonesRequest\x1a\x1f.beam.SetSpotlightZonesResponse\"\x00\x12\x65\n\x16SetSpotlightBrightness\x12#.beam.SetSpotlightBrightnessRequest\x1a$.beam.SetSpotlightBrightnessResponse\"\x00\x12S\n\x10ToggleFloodlight\x12\x1d.beam.ToggleFloodlightRequest\x1a\x1e.beam.ToggleFloodlightResponse\"\x00\x12\x86\x01\n!SetSpotlightLightOnPersonDetected\x12..beam.SetSpotlightLightOnPersonDetectedRequest\x1a/.beam.SetSpotlightLightOnPersonDetectedResponse\"\x00\x12h\n\x17SetSpotlightCalibration\x12$.beam.SetSpotlightCalibrationRequest\x1a%.beam.SetSpotlightCalibrationResponse\"\x00\x12k\n\x18SetDeterLightingBehavior\x12%.beam.SetDeterLightingBehaviorRequest\x1a&.beam.SetDeterLightingBehaviorResponse\"\x00\x12Y\n\x12SetSpotlightFollow\x12\x1f.beam.SetSpotlightFollowRequest\x1a .beam.SetSpotlightFollowResponse\"\x00\x12}\n\x1dSetSpotlightOnSunsetToSunrise\x12*.beam.SetSpotlightOnSunsetToSunriseRequest\x1a+.beam.SetSpotlightOnSunsetToSunriseResponse\"\x03\x88\x02\x01\x12\x65\n\x16SetSpotlightNightLight\x12#.beam.SetSpotlightNightLightRequest\x1a$.beam.SetSpotlightNightLightResponse\"\x00\x42I\n\x0f\x63om.vivint.grpcZ,source.vivint.com/pl/beam-def/generated;beam\xa2\x02\x07VIVBEAMb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'vivintpy.proto.beam_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\017com.vivint.grpcZ,source.vivint.com/pl/beam-def/generated;beam\242\002\007VIVBEAM'
  _SETDEVICENAMEREQUEST.fields_by_name['panel_id']._options = None
  _SETDEVICENAMEREQUEST.fields_by_name['panel_id']._serialized_options = b'\030\001'
  _SETDEVICENAMEREQUEST.fields_by_name['device_id']._options = None
  _SETDEVICENAMEREQUEST.fields_by_name['device_id']._serialized_options = b'\030\001'
  _GETCAMERASETTINGSREQUEST.fields_by_name['panel_id']._options = None
  _GETCAMERASETTINGSREQUEST.fields_by_name['panel_id']._serialized_options = b'\030\001'
  _GETCAMERASETTINGSREQUEST.fields_by_name['device_id']._options = None
  _GETCAMERASETTINGSREQUEST.fields_by_name['device_id']._serialized_options = b'\030\001'
  _GETCAMERASETTINGSRESPONSE.fields_by_name['package_watch_state']._options = None
  _GETCAMERASETTINGSRESPONSE.fields_by_name['package_watch_state']._serialized_options = b'\030\001'
  _SETTINGSREQUESTHEADER.fields_by_name['device_uuid']._options = None
  _SETTINGSREQUESTHEADER.fields_by_name['device_uuid']._serialized_options = b'\030\001'
  _SETAUDIORECORDINGREQUEST.fields_by_name['panel_id']._options = None
  _SETAUDIORECORDINGREQUEST.fields_by_name['panel_id']._serialized_options = b'\030\001'
  _SETAUDIORECORDINGREQUEST.fields_by_name['device_id']._options = None
  _SETAUDIORECORDINGREQUEST.fields_by_name['device_id']._serialized_options = b'\030\001'
  _SETDOORBELLCHIMEREQUEST.fields_by_name['panel_id']._options = None
  _SETDOORBELLCHIMEREQUEST.fields_by_name['panel_id']._serialized_options = b'\030\001'
  _SETDOORBELLCHIMEREQUEST.fields_by_name['device_id']._options = None
  _SETDOORBELLCHIMEREQUEST.fields_by_name['device_id']._serialized_options = b'\030\001'
  _SETDOORBELLCHIMEREQUEST.fields_by_name['device_uuid']._options = None
  _SETDOORBELLCHIMEREQUEST.fields_by_name['device_uuid']._serialized_options = b'\030\001'
  _SETPACKAGECHIMEREQUEST.fields_by_name['panel_id']._options = None
  _SETPACKAGECHIMEREQUEST.fields_by_name['panel_id']._serialized_options = b'\030\001'
  _SETPACKAGECHIMEREQUEST.fields_by_name['device_id']._options = None
  _SETPACKAGECHIMEREQUEST.fields_by_name['device_id']._serialized_options = b'\030\001'
  _GETANALYTICSOPTINREQUEST.fields_by_name['panel_id']._options = None
  _GETANALYTICSOPTINREQUEST.fields_by_name['panel_id']._serialized_options = b'\030\001'
  _GETANALYTICSOPTINREQUEST.fields_by_name['device_id']._options = None
  _GETANALYTICSOPTINREQUEST.fields_by_name['device_id']._serialized_options = b'\030\001'
  _SETANALYTICSOPTINREQUEST.fields_by_name['panel_id']._options = None
  _SETANALYTICSOPTINREQUEST.fields_by_name['panel_id']._serialized_options = b'\030\001'
  _SETANALYTICSOPTINREQUEST.fields_by_name['device_id']._options = None
  _SETANALYTICSOPTINREQUEST.fields_by_name['device_id']._serialized_options = b'\030\001'
  _SETNOTIFYONREQUEST.fields_by_name['panel_id']._options = None
  _SETNOTIFYONREQUEST.fields_by_name['panel_id']._serialized_options = b'\030\001'
  _SETNOTIFYONREQUEST.fields_by_name['device_id']._options = None
  _SETNOTIFYONREQUEST.fields_by_name['device_id']._serialized_options = b'\030\001'
  _DELETEALLEVENTSREQUEST.fields_by_name['panel_id']._options = None
  _DELETEALLEVENTSREQUEST.fields_by_name['panel_id']._serialized_options = b'\030\001'
  _DELETEALLEVENTSREQUEST.fields_by_name['device_id']._options = None
  _DELETEALLEVENTSREQUEST.fields_by_name['device_id']._serialized_options = b'\030\001'
  _SETPROPERTYBOUNDARYREQUEST.fields_by_name['panel_id']._options = None
  _SETPROPERTYBOUNDARYREQUEST.fields_by_name['panel_id']._serialized_options = b'\030\001'
  _SETPROPERTYBOUNDARYREQUEST.fields_by_name['device_id']._options = None
  _SETPROPERTYBOUNDARYREQUEST.fields_by_name['device_id']._serialized_options = b'\030\001'
  _SETANIMALBOUNDARYREQUEST.fields_by_name['panel_id']._options = None
  _SETANIMALBOUNDARYREQUEST.fields_by_name['panel_id']._serialized_options = b'\030\001'
  _SETANIMALBOUNDARYREQUEST.fields_by_name['device_id']._options = None
  _SETANIMALBOUNDARYREQUEST.fields_by_name['device_id']._serialized_options = b'\030\001'
  _SETPACKAGEBOUNDARYREQUEST.fields_by_name['panel_id']._options = None
  _SETPACKAGEBOUNDARYREQUEST.fields_by_name['panel_id']._serialized_options = b'\030\001'
  _SETPACKAGEBOUNDARYREQUEST.fields_by_name['device_id']._options = None
  _SETPACKAGEBOUNDARYREQUEST.fields_by_name['device_id']._serialized_options = b'\030\001'
  _SETVEHICLEBOUNDARYREQUEST.fields_by_name['panel_id']._options = None
  _SETVEHICLEBOUNDARYREQUEST.fields_by_name['panel_id']._serialized_options = b'\030\001'
  _SETVEHICLEBOUNDARYREQUEST.fields_by_name['device_id']._options = None
  _SETVEHICLEBOUNDARYREQUEST.fields_by_name['device_id']._serialized_options = b'\030\001'
  _SETDETERBOUNDARYREQUEST.fields_by_name['panel_id']._options = None
  _SETDETERBOUNDARYREQUEST.fields_by_name['panel_id']._serialized_options = b'\030\001'
  _SETDETERBOUNDARYREQUEST.fields_by_name['device_id']._options = None
  _SETDETERBOUNDARYREQUEST.fields_by_name['device_id']._serialized_options = b'\030\001'
  _SETPACKAGEDELIVERYLOCATIONSREQUEST.fields_by_name['panel_id']._options = None
  _SETPACKAGEDELIVERYLOCATIONSREQUEST.fields_by_name['panel_id']._serialized_options = b'\030\001'
  _SETPACKAGEDELIVERYLOCATIONSREQUEST.fields_by_name['device_id']._options = None
  _SETPACKAGEDELIVERYLOCATIONSREQUEST.fields_by_name['device_id']._serialized_options = b'\030\001'
  _GETDEVICEONBOARDINGREQUEST.fields_by_name['panel_id']._options = None
  _GETDEVICEONBOARDINGREQUEST.fields_by_name['panel_id']._serialized_options = b'\030\001'
  _GETDEVICEONBOARDINGREQUEST.fields_by_name['device_id']._options = None
  _GETDEVICEONBOARDINGREQUEST.fields_by_name['device_id']._serialized_options = b'\030\001'
  _SETDEVICEONBOARDINGREQUEST.fields_by_name['panel_id']._options = None
  _SETDEVICEONBOARDINGREQUEST.fields_by_name['panel_id']._serialized_options = b'\030\001'
  _SETDEVICEONBOARDINGREQUEST.fields_by_name['device_id']._options = None
  _SETDEVICEONBOARDINGREQUEST.fields_by_name['device_id']._serialized_options = b'\030\001'
  _SETDOORBELLPOSITIONREQUEST.fields_by_name['panel_id']._options = None
  _SETDOORBELLPOSITIONREQUEST.fields_by_name['panel_id']._serialized_options = b'\030\001'
  _SETDOORBELLPOSITIONREQUEST.fields_by_name['device_id']._options = None
  _SETDOORBELLPOSITIONREQUEST.fields_by_name['device_id']._serialized_options = b'\030\001'
  _SETPACKAGEWATCHSTATEREQUEST._options = None
  _SETPACKAGEWATCHSTATEREQUEST._serialized_options = b'\030\001'
  _SETPACKAGEWATCHSTATERESPONSE._options = None
  _SETPACKAGEWATCHSTATERESPONSE._serialized_options = b'\030\001'
  _SETSPOTLIGHTONSUNSETTOSUNRISEREQUEST._options = None
  _SETSPOTLIGHTONSUNSETTOSUNRISEREQUEST._serialized_options = b'\030\001'
  _SETSPOTLIGHTONSUNSETTOSUNRISERESPONSE._options = None
  _SETSPOTLIGHTONSUNSETTOSUNRISERESPONSE._serialized_options = b'\030\001'
  _BEAM.methods_by_name['SetPackageWatchState']._options = None
  _BEAM.methods_by_name['SetPackageWatchState']._serialized_options = b'\210\002\001'
  _BEAM.methods_by_name['SetSpotlightOnSunsetToSunrise']._options = None
  _BEAM.methods_by_name['SetSpotlightOnSunsetToSunrise']._serialized_options = b'\210\002\001'
  _DETERSCHEDULETYPE._serialized_start=22755
  _DETERSCHEDULETYPE._serialized_end=23090
  _DETERAGGRESSIONLEVEL._serialized_start=23092
  _DETERAGGRESSIONLEVEL._serialized_end=23201
  _DETERLIGHTCOLOR._serialized_start=23203
  _DETERLIGHTCOLOR._serialized_end=23241
  _DETERLIGHTPATTERN._serialized_start=23243
  _DETERLIGHTPATTERN._serialized_end=23296
  _VIDEOQUALITY._serialized_start=23298
  _VIDEOQUALITY._serialized_end=23377
  _DOORBELLCHIME._serialized_start=23380
  _DOORBELLCHIME._serialized_end=23542
  _VISITORCHIME._serialized_start=23545
  _VISITORCHIME._serialized_end=23707
  _PACKAGECHIME._serialized_start=23710
  _PACKAGECHIME._serialized_end=23935
  _RECORDFORREGIONS._serialized_start=23937
  _RECORDFORREGIONS._serialized_end=24038
  _CHIMETYPE._serialized_start=24040
  _CHIMETYPE._serialized_end=24115
  _DOORBELLPOSITION._serialized_start=24117
  _DOORBELLPOSITION._serialized_end=24208
  _SPOTLIGHTMODE._serialized_start=24211
  _SPOTLIGHTMODE._serialized_end=24386
  _SPOTLIGHTSTATUS._serialized_start=24389
  _SPOTLIGHTSTATUS._serialized_end=24685
  _SETDEVICENAMEREQUEST._serialized_start=97
  _SETDEVICENAMEREQUEST._serialized_end=223
  _SETDEVICENAMERESPONSE._serialized_start=225
  _SETDEVICENAMERESPONSE._serialized_end=282
  _GETCAMERATECHNICALINFOREQUEST._serialized_start=284
  _GETCAMERATECHNICALINFOREQUEST._serialized_end=352
  _GETCAMERATECHNICALINFORESPONSE._serialized_start=354
  _GETCAMERATECHNICALINFORESPONSE._serialized_end=455
  _GETCAMERASETTINGSREQUEST._serialized_start=457
  _GETCAMERASETTINGSREQUEST._serialized_end=573
  _GETCAMERASETTINGSRESPONSE._serialized_start=576
  _GETCAMERASETTINGSRESPONSE._serialized_end=4109
  _PANELDEVICEIDS._serialized_start=4111
  _PANELDEVICEIDS._serialized_end=4164
  _STANDALONECAMERAIDS._serialized_start=4166
  _STANDALONECAMERAIDS._serialized_end=4255
  _SETTINGSREQUESTHEADER._serialized_start=4258
  _SETTINGSREQUESTHEADER._serialized_end=4472
  _GETPANELSETTINGSREQUEST._serialized_start=4474
  _GETPANELSETTINGSREQUEST._serialized_end=4536
  _GETPANELSETTINGSRESPONSE._serialized_start=4538
  _GETPANELSETTINGSRESPONSE._serialized_end=4622
  _SETCAMERAPRIVACYMODEREQUEST._serialized_start=4624
  _SETCAMERAPRIVACYMODEREQUEST._serialized_end=4712
  _SETCAMERAPRIVACYMODERESPONSE._serialized_start=4714
  _SETCAMERAPRIVACYMODERESPONSE._serialized_end=4778
  _SETCAMERAPLAYBACKENABLEDREQUEST._serialized_start=4780
  _SETCAMERAPLAYBACKENABLEDREQUEST._serialized_end=4876
  _SETCAMERAPLAYBACKENABLEDRESPONSE._serialized_start=4878
  _SETCAMERAPLAYBACKENABLEDRESPONSE._serialized_end=4946
  _SETDETECTIONWINDOWSREQUEST._serialized_start=4948
  _SETDETECTIONWINDOWSREQUEST._serialized_end=5063
  _SETDETECTIONWINDOWSRESPONSE._serialized_start=5065
  _SETDETECTIONWINDOWSRESPONSE._serialized_end=5128
  _SETCHIMEVOLUMEREQUEST._serialized_start=5130
  _SETCHIMEVOLUMEREQUEST._serialized_end=5206
  _SETCHIMEVOLUMERESPONSE._serialized_start=5208
  _SETCHIMEVOLUMERESPONSE._serialized_end=5266
  _SETCHIMEMUTEREQUEST._serialized_start=5268
  _SETCHIMEMUTEREQUEST._serialized_end=5340
  _SETCHIMEMUTERESPONSE._serialized_start=5342
  _SETCHIMEMUTERESPONSE._serialized_end=5398
  _SETVIDEOQUALITYREQUEST._serialized_start=5400
  _SETVIDEOQUALITYREQUEST._serialized_end=5498
  _SETVIDEOQUALITYRESPONSE._serialized_start=5500
  _SETVIDEOQUALITYRESPONSE._serialized_end=5559
  _SETNIGHTVISIONREQUEST._serialized_start=5561
  _SETNIGHTVISIONREQUEST._serialized_end=5643
  _SETNIGHTVISIONRESPONSE._serialized_start=5645
  _SETNIGHTVISIONRESPONSE._serialized_end=5703
  _SETIRLEDREQUEST._serialized_start=5705
  _SETIRLEDREQUEST._serialized_end=5778
  _SETIRLEDRESPONSE._serialized_start=5780
  _SETIRLEDRESPONSE._serialized_end=5832
  _SETROTATEIMAGEREQUEST._serialized_start=5834
  _SETROTATEIMAGEREQUEST._serialized_end=5916
  _SETROTATEIMAGERESPONSE._serialized_start=5918
  _SETROTATEIMAGERESPONSE._serialized_end=5976
  _SETMAINTAINZOOMREQUEST._serialized_start=5978
  _SETMAINTAINZOOMREQUEST._serialized_end=6062
  _SETMAINTAINZOOMRESPONSE._serialized_start=6064
  _SETMAINTAINZOOMRESPONSE._serialized_end=6123
  _SETSTATUSLIGHTREQUEST._serialized_start=6125
  _SETSTATUSLIGHTREQUEST._serialized_end=6207
  _SETSTATUSLIGHTRESPONSE._serialized_start=6209
  _SETSTATUSLIGHTRESPONSE._serialized_end=6267
  _SETAUDIORECORDINGREQUEST._serialized_start=6270
  _SETAUDIORECORDINGREQUEST._serialized_end=6411
  _SETAUDIORECORDINGRESPONSE._serialized_start=6413
  _SETAUDIORECORDINGRESPONSE._serialized_end=6474
  _SETDOORBELLCHIMEREQUEST._serialized_start=6477
  _SETDOORBELLCHIMEREQUEST._serialized_end=6681
  _SETDOORBELLCHIMERESPONSE._serialized_start=6683
  _SETDOORBELLCHIMERESPONSE._serialized_end=6743
  _SETDOORBELLMUTEDREQUEST._serialized_start=6745
  _SETDOORBELLMUTEDREQUEST._serialized_end=6822
  _SETDOORBELLMUTEDRESPONSE._serialized_start=6824
  _SETDOORBELLMUTEDRESPONSE._serialized_end=6884
  _SETVISITORCHIMEREQUEST._serialized_start=6886
  _SETVISITORCHIMEREQUEST._serialized_end=6982
  _SETVISITORCHIMERESPONSE._serialized_start=6984
  _SETVISITORCHIMERESPONSE._serialized_end=7043
  _SETPACKAGECHIMEREQUEST._serialized_start=7046
  _SETPACKAGECHIMEREQUEST._serialized_end=7195
  _SETPACKAGECHIMERESPONSE._serialized_start=7197
  _SETPACKAGECHIMERESPONSE._serialized_end=7256
  _SETUSEASDOORBELLCHIMEEXTENDERREQUEST._serialized_start=7258
  _SETUSEASDOORBELLCHIMEEXTENDERREQUEST._serialized_end=7373
  _SETUSEASDOORBELLCHIMEEXTENDERRESPONSE._serialized_start=7375
  _SETUSEASDOORBELLCHIMEEXTENDERRESPONSE._serialized_end=7448
  _SETEXTENDSIRENREQUEST._serialized_start=7450
  _SETEXTENDSIRENREQUEST._serialized_end=7532
  _SETEXTENDSIRENRESPONSE._serialized_start=7534
  _SETEXTENDSIRENRESPONSE._serialized_end=7592
  _SETQUIETMODEREQUEST._serialized_start=7594
  _SETQUIETMODEREQUEST._serialized_end=7672
  _SETQUIETMODERESPONSE._serialized_start=7674
  _SETQUIETMODERESPONSE._serialized_end=7730
  _GETANALYTICSOPTINREQUEST._serialized_start=7732
  _GETANALYTICSOPTINREQUEST._serialized_end=7848
  _GETANALYTICSOPTINRESPONSE._serialized_start=7850
  _GETANALYTICSOPTINRESPONSE._serialized_end=7927
  _SETANALYTICSOPTINREQUEST._serialized_start=7930
  _SETANALYTICSOPTINREQUEST._serialized_end=8079
  _SETANALYTICSOPTINRESPONSE._serialized_start=8081
  _SETANALYTICSOPTINRESPONSE._serialized_end=8142
  _SETNOTIFYONREQUEST._serialized_start=8144
  _SETNOTIFYONREQUEST._serialized_end=8271
  _SETNOTIFYONRESPONSE._serialized_start=8273
  _SETNOTIFYONRESPONSE._serialized_end=8328
  _RESTOREDEFAULTSREQUEST._serialized_start=8330
  _RESTOREDEFAULTSREQUEST._serialized_end=8391
  _RESTOREDEFAULTSRESPONSE._serialized_start=8393
  _RESTOREDEFAULTSRESPONSE._serialized_end=8452
  _ADJUSTCAMERATOXYZREQUEST._serialized_start=8454
  _ADJUSTCAMERATOXYZREQUEST._serialized_end=8569
  _ADJUSTCAMERATOXYZRESPONSE._serialized_start=8571
  _ADJUSTCAMERATOXYZRESPONSE._serialized_end=8632
  _REBOOTCAMERAREQUEST._serialized_start=8634
  _REBOOTCAMERAREQUEST._serialized_end=8713
  _REBOOTCAMERARESPONSE._serialized_start=8715
  _REBOOTCAMERARESPONSE._serialized_end=8771
  _DELETEALLEVENTSREQUEST._serialized_start=8773
  _DELETEALLEVENTSREQUEST._serialized_end=8887
  _DELETEALLEVENTSRESPONSE._serialized_start=8889
  _DELETEALLEVENTSRESPONSE._serialized_end=8948
  _DELETECAMERAREQUEST._serialized_start=8950
  _DELETECAMERAREQUEST._serialized_end=9008
  _DELETECAMERARESPONSE._serialized_start=9010
  _DELETECAMERARESPONSE._serialized_end=9066
  _SETCAMERALISTORDERREQUEST._serialized_start=9068
  _SETCAMERALISTORDERREQUEST._serialized_end=9149
  _SETCAMERALISTORDERRESPONSE._serialized_start=9151
  _SETCAMERALISTORDERRESPONSE._serialized_end=9213
  _SETLURKERDETERREQUEST._serialized_start=9215
  _SETLURKERDETERREQUEST._serialized_end=9297
  _SETLURKERDETERRESPONSE._serialized_start=9299
  _SETLURKERDETERRESPONSE._serialized_end=9357
  _SETSMARTSENTRYSNOOZEREQUEST._serialized_start=9359
  _SETSMARTSENTRYSNOOZEREQUEST._serialized_end=9443
  _SETSMARTSENTRYSNOOZERESPONSE._serialized_start=9445
  _SETSMARTSENTRYSNOOZERESPONSE._serialized_end=9509
  _SETPACKAGEWATCHREQUEST._serialized_start=9511
  _SETPACKAGEWATCHREQUEST._serialized_end=9595
  _SETPACKAGEWATCHRESPONSE._serialized_start=9597
  _SETPACKAGEWATCHRESPONSE._serialized_end=9656
  _SETPROPERTYBOUNDARYREQUEST._serialized_start=9659
  _SETPROPERTYBOUNDARYREQUEST._serialized_end=9830
  _SETPROPERTYBOUNDARYRESPONSE._serialized_start=9832
  _SETPROPERTYBOUNDARYRESPONSE._serialized_end=9895
  _SETDETERSCHEDULEREQUEST._serialized_start=9898
  _SETDETERSCHEDULEREQUEST._serialized_end=10038
  _SETDETERSCHEDULERESPONSE._serialized_start=10040
  _SETDETERSCHEDULERESPONSE._serialized_end=10100
  _SETDETERSCHEDULEV2REQUEST._serialized_start=10102
  _SETDETERSCHEDULEV2REQUEST._serialized_end=10224
  _SETDETERSCHEDULEV2RESPONSE._serialized_start=10226
  _SETDETERSCHEDULEV2RESPONSE._serialized_end=10288
  _DETERSCHEDULESETTINGSV2._serialized_start=10290
  _DETERSCHEDULESETTINGSV2._serialized_end=10409
  _ASPECTRATIOTUPLE._serialized_start=10411
  _ASPECTRATIOTUPLE._serialized_end=10460
  _SETDETERAGGRESSIONLEVELREQUEST._serialized_start=10462
  _SETDETERAGGRESSIONLEVELREQUEST._serialized_end=10574
  _SETDETERAGGRESSIONLEVELRESPONSE._serialized_start=10576
  _SETDETERAGGRESSIONLEVELRESPONSE._serialized_end=10643
  _SETDETERLIGHTCOLORREQUEST._serialized_start=10645
  _SETDETERLIGHTCOLORREQUEST._serialized_end=10747
  _SETDETERLIGHTCOLORRESPONSE._serialized_start=10749
  _SETDETERLIGHTCOLORRESPONSE._serialized_end=10811
  _SETDETERLIGHTPATTERNREQUEST._serialized_start=10813
  _SETDETERLIGHTPATTERNREQUEST._serialized_end=10921
  _SETDETERLIGHTPATTERNRESPONSE._serialized_start=10923
  _SETDETERLIGHTPATTERNRESPONSE._serialized_end=10987
  _SETDETEROVERRIDEREQUEST._serialized_start=10989
  _SETDETEROVERRIDEREQUEST._serialized_end=11091
  _SETDETEROVERRIDERESPONSE._serialized_start=11093
  _SETDETEROVERRIDERESPONSE._serialized_end=11153
  _SETLINGERDURATIONREQUEST._serialized_start=11155
  _SETLINGERDURATIONREQUEST._serialized_end=11236
  _SETLINGERDURATIONRESPONSE._serialized_start=11238
  _SETLINGERDURATIONRESPONSE._serialized_end=11299
  _SETANIMALBOUNDARYREQUEST._serialized_start=11302
  _SETANIMALBOUNDARYREQUEST._serialized_end=11471
  _SETANIMALBOUNDARYRESPONSE._serialized_start=11473
  _SETANIMALBOUNDARYRESPONSE._serialized_end=11534
  _SETPACKAGEBOUNDARYREQUEST._serialized_start=11537
  _SETPACKAGEBOUNDARYREQUEST._serialized_end=11707
  _SETPACKAGEBOUNDARYRESPONSE._serialized_start=11709
  _SETPACKAGEBOUNDARYRESPONSE._serialized_end=11771
  _SETVEHICLEBOUNDARYREQUEST._serialized_start=11774
  _SETVEHICLEBOUNDARYREQUEST._serialized_end=11944
  _SETVEHICLEBOUNDARYRESPONSE._serialized_start=11946
  _SETVEHICLEBOUNDARYRESPONSE._serialized_end=12008
  _SETDETERBOUNDARYREQUEST._serialized_start=12011
  _SETDETERBOUNDARYREQUEST._serialized_end=12179
  _SETDETERBOUNDARYRESPONSE._serialized_start=12181
  _SETDETERBOUNDARYRESPONSE._serialized_end=12241
  _GETPANELLOGINREQUEST._serialized_start=12243
  _GETPANELLOGINREQUEST._serialized_end=12283
  _GETPANELLOGINRESPONSE._serialized_start=12285
  _GETPANELLOGINRESPONSE._serialized_end=12374
  _SETCAPTURECLIPONREQUEST._serialized_start=12376
  _SETCAPTURECLIPONREQUEST._serialized_end=12463
  _SETCAPTURECLIPONRESPONSE._serialized_start=12465
  _SETCAPTURECLIPONRESPONSE._serialized_end=12525
  _SETRECORDONDETERREQUEST._serialized_start=12527
  _SETRECORDONDETERREQUEST._serialized_end=12614
  _SETRECORDONDETERRESPONSE._serialized_start=12616
  _SETRECORDONDETERRESPONSE._serialized_end=12676
  _SETRECORDONPERSONDETECTEDREQUEST._serialized_start=12678
  _SETRECORDONPERSONDETECTEDREQUEST._serialized_end=12775
  _SETRECORDONPERSONDETECTEDRESPONSE._serialized_start=12777
  _SETRECORDONPERSONDETECTEDRESPONSE._serialized_end=12846
  _SETRECORDONPACKAGEDETECTEDREQUEST._serialized_start=12848
  _SETRECORDONPACKAGEDETECTEDREQUEST._serialized_end=12947
  _SETRECORDONPACKAGEDETECTEDRESPONSE._serialized_start=12949
  _SETRECORDONPACKAGEDETECTEDRESPONSE._serialized_end=13019
  _SETRECORDONLURKERDETECTEDREQUEST._serialized_start=13021
  _SETRECORDONLURKERDETECTEDREQUEST._serialized_end=13118
  _SETRECORDONLURKERDETECTEDRESPONSE._serialized_start=13120
  _SETRECORDONLURKERDETECTEDRESPONSE._serialized_end=13189
  _SETRECORDONANIMALDETECTEDREQUEST._serialized_start=13191
  _SETRECORDONANIMALDETECTEDREQUEST._serialized_end=13288
  _SETRECORDONANIMALDETECTEDRESPONSE._serialized_start=13290
  _SETRECORDONANIMALDETECTEDRESPONSE._serialized_end=13359
  _SETRECORDONVEHICLEDETECTEDREQUEST._serialized_start=13361
  _SETRECORDONVEHICLEDETECTEDREQUEST._serialized_end=13460
  _SETRECORDONVEHICLEDETECTEDRESPONSE._serialized_start=13462
  _SETRECORDONVEHICLEDETECTEDRESPONSE._serialized_end=13532
  _SETRECORDFORREGIONSREQUEST._serialized_start=13534
  _SETRECORDFORREGIONSREQUEST._serialized_end=13650
  _SETRECORDFORREGIONSRESPONSE._serialized_start=13652
  _SETRECORDFORREGIONSRESPONSE._serialized_end=13715
  _SETANALYTICSSENSITIVITYREQUEST._serialized_start=13717
  _SETANALYTICSSENSITIVITYREQUEST._serialized_end=13817
  _SETANALYTICSSENSITIVITYRESPONSE._serialized_start=13819
  _SETANALYTICSSENSITIVITYRESPONSE._serialized_end=13886
  _PREVIEWCHIMEREQUEST._serialized_start=13888
  _PREVIEWCHIMEREQUEST._serialized_end=13983
  _SETPACKAGEDELIVERYLOCATIONSRESPONSE._serialized_start=13985
  _SETPACKAGEDELIVERYLOCATIONSRESPONSE._serialized_end=14056
  _SETPACKAGEDELIVERYLOCATIONSREQUEST._serialized_start=14059
  _SETPACKAGEDELIVERYLOCATIONSREQUEST._serialized_end=14250
  _PREVIEWCHIMERESPONSE._serialized_start=14252
  _PREVIEWCHIMERESPONSE._serialized_end=14308
  _GETDEVICEONBOARDINGREQUEST._serialized_start=14310
  _GETDEVICEONBOARDINGREQUEST._serialized_end=14428
  _GETDEVICEONBOARDINGRESPONSE._serialized_start=14431
  _GETDEVICEONBOARDINGRESPONSE._serialized_end=15036
  _SETDEVICEONBOARDINGREQUEST._serialized_start=15039
  _SETDEVICEONBOARDINGREQUEST._serialized_end=15749
  _SETDEVICEONBOARDINGRESPONSE._serialized_start=15751
  _SETDEVICEONBOARDINGRESPONSE._serialized_end=15814
  _SETDOORBELLPOSITIONREQUEST._serialized_start=15817
  _SETDOORBELLPOSITIONREQUEST._serialized_end=15986
  _SETDOORBELLPOSITIONRESPONSE._serialized_start=15988
  _SETDOORBELLPOSITIONRESPONSE._serialized_end=16051
  _SETPACKAGEWATCHSTATEREQUEST._serialized_start=16053
  _SETPACKAGEWATCHSTATEREQUEST._serialized_end=16163
  _SETPACKAGEWATCHSTATERESPONSE._serialized_start=16165
  _SETPACKAGEWATCHSTATERESPONSE._serialized_end=16233
  _DYNAMICCHIMEINFO._serialized_start=16235
  _DYNAMICCHIMEINFO._serialized_end=16312
  _DYNAMICCHIMEBANNERINFO._serialized_start=16314
  _DYNAMICCHIMEBANNERINFO._serialized_end=16425
  _DYNAMICCHIMESPLASHPAGEINFO._serialized_start=16428
  _DYNAMICCHIMESPLASHPAGEINFO._serialized_end=16600
  _DYNAMICCHIMESPLASHPAGEBULLETINFO._serialized_start=16602
  _DYNAMICCHIMESPLASHPAGEBULLETINFO._serialized_end=16668
  _DYNAMICCHIMECATEGORY._serialized_start=16671
  _DYNAMICCHIMECATEGORY._serialized_end=17050
  _GETDYNAMICCHIMESREQUEST._serialized_start=17053
  _GETDYNAMICCHIMESREQUEST._serialized_end=17181
  _GETDYNAMICCHIMESRESPONSE._serialized_start=17183
  _GETDYNAMICCHIMESRESPONSE._serialized_end=17295
  _SETDYNAMICCHIMEREQUEST._serialized_start=17298
  _SETDYNAMICCHIMEREQUEST._serialized_end=17441
  _SETDYNAMICCHIMERESPONSE._serialized_start=17443
  _SETDYNAMICCHIMERESPONSE._serialized_end=17502
  _SETUSERROLEREQUEST._serialized_start=17505
  _SETUSERROLEREQUEST._serialized_end=17706
  _SETUSERROLEREQUEST_USERROLE._serialized_start=17646
  _SETUSERROLEREQUEST_USERROLE._serialized_end=17706
  _SETUSERROLERESPONSE._serialized_start=17708
  _SETUSERROLERESPONSE._serialized_end=17763
  _DATE._serialized_start=17765
  _DATE._serialized_end=17813
  _GETCLIPSHARINGLINKREQUEST._serialized_start=17816
  _GETCLIPSHARINGLINKREQUEST._serialized_end=17949
  _GETCLIPSHARINGLINKRESPONSE._serialized_start=17951
  _GETCLIPSHARINGLINKRESPONSE._serialized_end=18040
  _REPORTVIDEOFAILEDREQUEST._serialized_start=18043
  _REPORTVIDEOFAILEDREQUEST._serialized_end=18354
  _REPORTVIDEOFAILEDRESPONSE._serialized_start=18356
  _REPORTVIDEOFAILEDRESPONSE._serialized_end=18437
  _PANELKILLWIFINETWORKREQUEST._serialized_start=18439
  _PANELKILLWIFINETWORKREQUEST._serialized_end=18486
  _PANELREFRESHSSIDLISTREQUEST._serialized_start=18488
  _PANELREFRESHSSIDLISTREQUEST._serialized_end=18559
  _STARTCAMERAWIFICONNECTRESPONSE._serialized_start=18561
  _STARTCAMERAWIFICONNECTRESPONSE._serialized_end=18627
  _STARTCAMERAWIFICONNECTREQUEST._serialized_start=18629
  _STARTCAMERAWIFICONNECTREQUEST._serialized_end=18703
  _ADDCAMERATOHUBREQUEST._serialized_start=18705
  _ADDCAMERATOHUBREQUEST._serialized_end=18814
  _ACCESSPOINTINFO._serialized_start=18817
  _ACCESSPOINTINFO._serialized_end=18950
  _RESPONSE._serialized_start=18952
  _RESPONSE._serialized_end=19009
  _SOFTWAREVERSION._serialized_start=19011
  _SOFTWAREVERSION._serialized_end=19094
  _TYPECAPABILITIES._serialized_start=19096
  _TYPECAPABILITIES._serialized_end=19150
  _CAPABILITIES._serialized_start=19152
  _CAPABILITIES._serialized_end=19215
  _TECHNICALINFO._serialized_start=19218
  _TECHNICALINFO._serialized_end=19541
  _TECHNICALINFO_AUDIOCODEC._serialized_start=19488
  _TECHNICALINFO_AUDIOCODEC._serialized_end=19541
  _DETECTIONWINDOW._serialized_start=19544
  _DETECTIONWINDOW._serialized_end=19685
  _PROPERTYBOUNDARYPOINTLIST._serialized_start=19687
  _PROPERTYBOUNDARYPOINTLIST._serialized_end=19759
  _PROPERTYBOUNDARYPOINT._serialized_start=19761
  _PROPERTYBOUNDARYPOINT._serialized_end=19806
  _DETERSCHEDULE._serialized_start=19809
  _DETERSCHEDULE._serialized_end=19971
  _CAMERATHUMBNAILREQUEST._serialized_start=19973
  _CAMERATHUMBNAILREQUEST._serialized_end=20056
  _CAMERATHUMBNAILRESPONSE._serialized_start=20058
  _CAMERATHUMBNAILRESPONSE._serialized_end=20117
  _SYSTEMREQUESTHEADER._serialized_start=20119
  _SYSTEMREQUESTHEADER._serialized_end=20188
  _GETHISTORYCLIPURLREQUEST._serialized_start=20191
  _GETHISTORYCLIPURLREQUEST._serialized_end=20339
  _GETLEGACYHISTORYCLIPURLREQUEST._serialized_start=20341
  _GETLEGACYHISTORYCLIPURLREQUEST._serialized_end=20400
  _GETHISTORYCLIPURLRESPONSE._serialized_start=20402
  _GETHISTORYCLIPURLRESPONSE._serialized_end=20481
  _ASSOCIATEDVRREQUEST._serialized_start=20483
  _ASSOCIATEDVRREQUEST._serialized_end=20556
  _ASSOCIATEDVRRESPONSE._serialized_start=20558
  _ASSOCIATEDVRRESPONSE._serialized_end=20604
  _SPOTLIGHTCALIBRATIONDATA._serialized_start=20607
  _SPOTLIGHTCALIBRATIONDATA._serialized_end=20905
  _SPOTLIGHTCALIBRATIONDATA_ZONEDATA._serialized_start=20765
  _SPOTLIGHTCALIBRATIONDATA_ZONEDATA._serialized_end=20830
  _SPOTLIGHTCALIBRATIONDATA_CALIBRATIONTYPE._serialized_start=20832
  _SPOTLIGHTCALIBRATIONDATA_CALIBRATIONTYPE._serialized_end=20905
  _SETSPOTLIGHTCALIBRATIONREQUEST._serialized_start=20908
  _SETSPOTLIGHTCALIBRATIONREQUEST._serialized_end=21043
  _SETSPOTLIGHTCALIBRATIONRESPONSE._serialized_start=21045
  _SETSPOTLIGHTCALIBRATIONRESPONSE._serialized_end=21112
  _SETSPOTLIGHTZONESREQUEST._serialized_start=21114
  _SETSPOTLIGHTZONESREQUEST._serialized_end=21217
  _SETSPOTLIGHTZONESRESPONSE._serialized_start=21219
  _SETSPOTLIGHTZONESRESPONSE._serialized_end=21280
  _SETSPOTLIGHTLIGHTONPERSONDETECTEDREQUEST._serialized_start=21282
  _SETSPOTLIGHTLIGHTONPERSONDETECTEDREQUEST._serialized_end=21400
  _SETSPOTLIGHTLIGHTONPERSONDETECTEDRESPONSE._serialized_start=21402
  _SETSPOTLIGHTLIGHTONPERSONDETECTEDRESPONSE._serialized_end=21479
  _SETSPOTLIGHTBRIGHTNESSREQUEST._serialized_start=21481
  _SETSPOTLIGHTBRIGHTNESSREQUEST._serialized_end=21585
  _SETSPOTLIGHTBRIGHTNESSRESPONSE._serialized_start=21587
  _SETSPOTLIGHTBRIGHTNESSRESPONSE._serialized_end=21653
  _TOGGLEFLOODLIGHTREQUEST._serialized_start=21655
  _TOGGLEFLOODLIGHTREQUEST._serialized_end=21748
  _TOGGLEFLOODLIGHTRESPONSE._serialized_start=21750
  _TOGGLEFLOODLIGHTRESPONSE._serialized_end=21810
  _SETSPOTLIGHTONSUNSETTOSUNRISEREQUEST._serialized_start=21812
  _SETSPOTLIGHTONSUNSETTOSUNRISEREQUEST._serialized_end=21916
  _SETSPOTLIGHTONSUNSETTOSUNRISERESPONSE._serialized_start=21918
  _SETSPOTLIGHTONSUNSETTOSUNRISERESPONSE._serialized_end=21995
  _SETSPOTLIGHTNIGHTLIGHTREQUEST._serialized_start=21997
  _SETSPOTLIGHTNIGHTLIGHTREQUEST._serialized_end=22090
  _SETSPOTLIGHTNIGHTLIGHTRESPONSE._serialized_start=22092
  _SETSPOTLIGHTNIGHTLIGHTRESPONSE._serialized_end=22158
  _BEAMPORTALCOMMAND._serialized_start=22160
  _BEAMPORTALCOMMAND._serialized_end=22248
  _LIGHTINGBEHAVIOR._serialized_start=22251
  _LIGHTINGBEHAVIOR._serialized_end=22397
  _LIGHTINGBEHAVIOR_BEHAVIOR._serialized_start=22322
  _LIGHTINGBEHAVIOR_BEHAVIOR._serialized_end=22397
  _SETDETERLIGHTINGBEHAVIORREQUEST._serialized_start=22400
  _SETDETERLIGHTINGBEHAVIORREQUEST._serialized_end=22528
  _SETDETERLIGHTINGBEHAVIORRESPONSE._serialized_start=22530
  _SETDETERLIGHTINGBEHAVIORRESPONSE._serialized_end=22598
  _SETSPOTLIGHTFOLLOWREQUEST._serialized_start=22600
  _SETSPOTLIGHTFOLLOWREQUEST._serialized_end=22688
  _SETSPOTLIGHTFOLLOWRESPONSE._serialized_start=22690
  _SETSPOTLIGHTFOLLOWRESPONSE._serialized_end=22752
  _BEAM._serialized_start=24688
  _BEAM._serialized_end=33355
# @@protoc_insertion_point(module_scope)
